import * as i0 from '@angular/core';
import { Directive, Input, EventEmitter, Component, ContentChildren, Output, NgModule } from '@angular/core';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i2 from '@mintplayer/ng-bootstrap/grid';
import { BsGridModule } from '@mintplayer/ng-bootstrap/grid';
import * as i3 from '@mintplayer/ng-bootstrap/table';
import { BsTableModule } from '@mintplayer/ng-bootstrap/table';
import * as i4 from '@mintplayer/ng-bootstrap/pagination';
import { BsPaginationModule } from '@mintplayer/ng-bootstrap/pagination';
import { BehaviorSubject, map } from 'rxjs';

class DatatableSettings {
    constructor(data) {
        this.sortProperty = '';
        this.sortDirection = 'ascending';
        Object.assign(this, data);
        if (data && data.perPage) {
            this.perPage = data.perPage;
        }
        else {
            // Set default value
            this.perPage = {
                values: [10, 20, 50],
                selected: 20
            };
        }
        if (data && data.page) {
            this.page = data.page;
        }
        else {
            // Set default value
            this.page = {
                values: [1],
                selected: 1
            };
        }
    }
    toPagination() {
        const res = {
            sortProperty: this.sortProperty,
            sortDirection: this.sortDirection,
            perPage: this.perPage.selected,
            page: this.page.selected
        };
        return res;
    }
}

class BsDatatableColumnDirective {
    constructor(templateRef) {
        this.name = '';
        this.sortable = true;
        this.templateRef = templateRef;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsDatatableColumnDirective, deps: [{ token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.1.2", type: BsDatatableColumnDirective, selector: "[bsDatatableColumn]", inputs: { name: ["bsDatatableColumn", "name"], sortable: ["bsDatatableColumnSortable", "sortable"] }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsDatatableColumnDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[bsDatatableColumn]'
                }]
        }], ctorParameters: function () { return [{ type: i0.TemplateRef }]; }, propDecorators: { name: [{
                type: Input,
                args: ['bsDatatableColumn']
            }], sortable: [{
                type: Input,
                args: ['bsDatatableColumnSortable']
            }] } });

class BsDatatableComponent {
    constructor() {
        //#region Columns
        this.columns$ = new BehaviorSubject([]);
        this.settingsChange = new EventEmitter();
        this.settings = new DatatableSettings();
        this.settings.sortProperty = '';
        this.settings.sortDirection = 'ascending';
        this.settings.perPage = { values: [10, 20, 50], selected: 20 };
        this.settings.page = { values: [1], selected: 1 };
        this.numberOfColumns$ = this.columns$.pipe(map(columns => columns.length));
    }
    set columns(value) {
        this.columns$.next(value);
    }
    columnHeaderClicked(column) {
        if (column.sortable) {
            if (this.settings.sortProperty !== column.name) {
                this.settings.sortProperty = column.name;
                this.settings.sortDirection = 'ascending';
            }
            else if (this.settings.sortDirection === 'descending') {
                this.settings.sortDirection = 'ascending';
            }
            else {
                this.settings.sortDirection = 'descending';
            }
            this.settingsChange.emit(this.settings);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsDatatableComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.1.2", type: BsDatatableComponent, selector: "bs-datatable", inputs: { settings: "settings" }, outputs: { settingsChange: "settingsChange" }, queries: [{ propertyName: "columns", predicate: BsDatatableColumnDirective }], ngImport: i0, template: "<bs-table [isResponsive]=\"true\" [striped]=\"true\" [hover]=\"true\" class=\"mb-3\">\n    <thead>\n        <tr>\n            <th *ngFor=\"let column of (columns$ | async)\" class=\"text-nowrap\"\n                [class.sort]=\"column.sortable\"\n                [class.sort-asc]=\"column.sortable && (settings.sortProperty === column.name) && (settings.sortDirection === 'ascending')\"\n                [class.sort-desc]=\"column.sortable && (settings.sortProperty === column.name) && (settings.sortDirection === 'descending')\"\n                (click)=\"columnHeaderClicked(column)\">\n                <ng-container *ngTemplateOutlet=\"column.templateRef\"></ng-container>\n            </th>\n        </tr>\n    </thead>\n    <tbody>\n        <ng-container *ngIf=\"!!data && !!rowTemplate\">\n            <ng-container *ngFor=\"let item of data.data\">\n                <ng-container *ngTemplateOutlet=\"rowTemplate; context: { $implicit: item }\"></ng-container>\n            </ng-container>\n        </ng-container>\n    </tbody>\n    <tfoot>\n        <tr>\n            <td [colSpan]=\"numberOfColumns$ | async\">\n                <bs-grid [stopFullWidthAt]=\"'never'\">\n                    <div bsRow>\n                        <div [bsColumn]=\"{md: 12}\">\n                            <bs-pagination class=\"float-start\" [pageNumbers]=\"settings.perPage.values\"\n                                [(selectedPageNumber)]=\"settings.perPage.selected\" (selectedPageNumberChange)=\"settingsChange.emit(settings)\"\n                                [showArrows]=\"false\"></bs-pagination>\n                            <bs-pagination class=\"float-end\" [pageNumbers]=\"settings.page.values\"\n                                [(selectedPageNumber)]=\"settings.page.selected\" (selectedPageNumberChange)=\"settingsChange.emit(settings)\"\n                                [showArrows]=\"true\"></bs-pagination>\n                        </div>\n                    </div>\n                </bs-grid>\n            </td>\n        </tr>\n    </tfoot>\n</bs-table>", styles: ["@charset \"UTF-8\";tfoot>tr>td{border-bottom:none}bs-table thead th.sort{position:relative;cursor:pointer;padding-right:2rem}bs-table thead th.sort:before,bs-table thead th.sort:after{position:absolute;display:block;opacity:.3;bottom:.5em}bs-table thead th.sort:before{content:\"\\2191\";right:1em}bs-table thead th.sort:after{content:\"\\2193\";right:.5em}bs-table thead th.sort.sort-asc:after{opacity:1}bs-table thead th.sort.sort-desc:before{opacity:1}\n"], dependencies: [{ kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: i2.BsGridComponent, selector: "bs-grid", inputs: ["stopFullWidthAt"] }, { kind: "directive", type: i2.BsGridRowDirective, selector: "[bsRow]" }, { kind: "directive", type: i2.BsGridColumnDirective, selector: "[bsColumn]", inputs: ["bsColumn"] }, { kind: "component", type: i3.BsTableComponent, selector: "bs-table", inputs: ["isResponsive", "striped", "hover"] }, { kind: "component", type: i4.BsPaginationComponent, selector: "bs-pagination", inputs: ["selectedPageNumber", "numberOfBoxes", "pageNumbers", "showArrows", "size"], outputs: ["selectedPageNumberChange"] }, { kind: "pipe", type: i1.AsyncPipe, name: "async" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsDatatableComponent, decorators: [{
            type: Component,
            args: [{ selector: 'bs-datatable', template: "<bs-table [isResponsive]=\"true\" [striped]=\"true\" [hover]=\"true\" class=\"mb-3\">\n    <thead>\n        <tr>\n            <th *ngFor=\"let column of (columns$ | async)\" class=\"text-nowrap\"\n                [class.sort]=\"column.sortable\"\n                [class.sort-asc]=\"column.sortable && (settings.sortProperty === column.name) && (settings.sortDirection === 'ascending')\"\n                [class.sort-desc]=\"column.sortable && (settings.sortProperty === column.name) && (settings.sortDirection === 'descending')\"\n                (click)=\"columnHeaderClicked(column)\">\n                <ng-container *ngTemplateOutlet=\"column.templateRef\"></ng-container>\n            </th>\n        </tr>\n    </thead>\n    <tbody>\n        <ng-container *ngIf=\"!!data && !!rowTemplate\">\n            <ng-container *ngFor=\"let item of data.data\">\n                <ng-container *ngTemplateOutlet=\"rowTemplate; context: { $implicit: item }\"></ng-container>\n            </ng-container>\n        </ng-container>\n    </tbody>\n    <tfoot>\n        <tr>\n            <td [colSpan]=\"numberOfColumns$ | async\">\n                <bs-grid [stopFullWidthAt]=\"'never'\">\n                    <div bsRow>\n                        <div [bsColumn]=\"{md: 12}\">\n                            <bs-pagination class=\"float-start\" [pageNumbers]=\"settings.perPage.values\"\n                                [(selectedPageNumber)]=\"settings.perPage.selected\" (selectedPageNumberChange)=\"settingsChange.emit(settings)\"\n                                [showArrows]=\"false\"></bs-pagination>\n                            <bs-pagination class=\"float-end\" [pageNumbers]=\"settings.page.values\"\n                                [(selectedPageNumber)]=\"settings.page.selected\" (selectedPageNumberChange)=\"settingsChange.emit(settings)\"\n                                [showArrows]=\"true\"></bs-pagination>\n                        </div>\n                    </div>\n                </bs-grid>\n            </td>\n        </tr>\n    </tfoot>\n</bs-table>", styles: ["@charset \"UTF-8\";tfoot>tr>td{border-bottom:none}bs-table thead th.sort{position:relative;cursor:pointer;padding-right:2rem}bs-table thead th.sort:before,bs-table thead th.sort:after{position:absolute;display:block;opacity:.3;bottom:.5em}bs-table thead th.sort:before{content:\"\\2191\";right:1em}bs-table thead th.sort:after{content:\"\\2193\";right:.5em}bs-table thead th.sort.sort-asc:after{opacity:1}bs-table thead th.sort.sort-desc:before{opacity:1}\n"] }]
        }], ctorParameters: function () { return []; }, propDecorators: { columns: [{
                type: ContentChildren,
                args: [BsDatatableColumnDirective]
            }], settings: [{
                type: Input
            }], settingsChange: [{
                type: Output
            }] } });

class BsRowTemplateDirective {
    constructor(datatableComponent, templateRef) {
        this.datatableComponent = datatableComponent;
        this.datatableComponent.rowTemplate = templateRef;
    }
    set bsRowTemplateOf(value) {
        this.datatableComponent.data = value;
    }
    static ngTemplateContextGuard(dir, ctx) {
        return true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsRowTemplateDirective, deps: [{ token: BsDatatableComponent }, { token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.1.2", type: BsRowTemplateDirective, selector: "[bsRowTemplate]", inputs: { bsRowTemplateOf: "bsRowTemplateOf" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsRowTemplateDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[bsRowTemplate]'
                }]
        }], ctorParameters: function () { return [{ type: BsDatatableComponent }, { type: i0.TemplateRef }]; }, propDecorators: { bsRowTemplateOf: [{
                type: Input
            }] } });
class BsRowTemplateContext {
    constructor() {
        this.$implicit = null;
    }
}

class BsDatatableModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsDatatableModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.1.2", ngImport: i0, type: BsDatatableModule, declarations: [BsDatatableComponent,
            BsDatatableColumnDirective,
            BsRowTemplateDirective], imports: [CommonModule,
            BsGridModule,
            BsTableModule,
            BsPaginationModule], exports: [BsDatatableComponent,
            BsDatatableColumnDirective,
            BsRowTemplateDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsDatatableModule, imports: [CommonModule,
            BsGridModule,
            BsTableModule,
            BsPaginationModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsDatatableModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        BsDatatableComponent,
                        BsDatatableColumnDirective,
                        BsRowTemplateDirective
                    ],
                    imports: [
                        CommonModule,
                        BsGridModule,
                        BsTableModule,
                        BsPaginationModule
                    ],
                    exports: [
                        BsDatatableComponent,
                        BsDatatableColumnDirective,
                        BsRowTemplateDirective
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { BsDatatableColumnDirective, BsDatatableComponent, BsDatatableModule, BsRowTemplateContext, BsRowTemplateDirective, DatatableSettings };
//# sourceMappingURL=mintplayer-ng-bootstrap-datatable.mjs.map
