import * as i0 from '@angular/core';
import { Component, HostListener, ViewChild, Input, PLATFORM_ID, Inject, Optional, ContentChildren, forwardRef, SkipSelf, Host, Directive, HostBinding, EventEmitter, Output, NgModule } from '@angular/core';
import * as i1 from '@angular/common';
import { isPlatformServer, DOCUMENT, CommonModule } from '@angular/common';
import * as i2$1 from '@mintplayer/ng-click-outside';
import { ClickOutsideModule } from '@mintplayer/ng-click-outside';
import * as i3 from '@mintplayer/ng-bootstrap/user-agent';
import { BsUserAgentModule } from '@mintplayer/ng-bootstrap/user-agent';
import * as i4 from '@mintplayer/ng-bootstrap/no-noscript';
import { BsNoNoscriptModule } from '@mintplayer/ng-bootstrap/no-noscript';
import * as i4$1 from '@mintplayer/ng-bootstrap/has-overlay';
import { BsHasOverlayModule } from '@mintplayer/ng-bootstrap/has-overlay';
import { BsDropdownDividerModule, BsDropdownDividerDirective } from '@mintplayer/ng-bootstrap/dropdown-divider';
import * as i2 from '@mintplayer/ng-bootstrap/container';
import { BsContainerModule } from '@mintplayer/ng-bootstrap/container';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';
import { Color } from '@mintplayer/ng-bootstrap';
import { BehaviorSubject, map, combineLatest, filter, debounceTime, take } from 'rxjs';
import { SlideUpDownAnimation } from '@mintplayer/ng-animations';
import { DomPortal } from '@angular/cdk/portal';

class BsNavbarComponent {
    constructor() {
        this.autoclose = true;
        this.expandButtonTemplate = null;
        this.isExpanded$ = new BehaviorSubject(false);
        this.windowWidth$ = new BehaviorSubject(null);
        this.isResizing$ = new BehaviorSubject(false);
        //#region Color
        this.color$ = new BehaviorSubject(null);
        //#endregion
        //#region Breakpoint
        this.breakPoint$ = new BehaviorSubject('md');
        this.expandAt$ = this.breakPoint$
            .pipe(map((breakpoint) => {
            switch (breakpoint) {
                case 'xxl': return 1400;
                case 'xl': return 1200;
                case 'lg': return 992;
                case 'md': return 768;
                case 'sm': return 576;
                case 'xs': return 0;
                default: return null;
            }
        }));
        this.isSmallMode$ = combineLatest([this.expandAt$, this.windowWidth$])
            .pipe(filter(([expandAt, windowWidth]) => {
            return windowWidth !== null;
        }))
            .pipe(map(([expandAt, windowWidth]) => {
            if (windowWidth === null) {
                throw 'windowWidth should not be null here';
            }
            else if (!expandAt) {
                return true;
            }
            else if (windowWidth >= expandAt) {
                return false;
            }
            else {
                return true;
            }
        }));
        this.windowWidth$
            .pipe(debounceTime(300), takeUntilDestroyed())
            .subscribe(() => this.isResizing$.next(false));
        this.onWindowResize();
        this.expandClass$ = this.breakPoint$.pipe(map((breakpoint) => {
            if (breakpoint === null) {
                return null;
            }
            else {
                return `navbar-expand-${breakpoint}`;
            }
        }));
        this.wAutoClass$ = this.breakPoint$.pipe(map((breakpoint) => {
            if (breakpoint === null) {
                return null;
            }
            else {
                return `w-${breakpoint}-auto`;
            }
        }));
        this.dNoneClass$ = this.breakPoint$.pipe(map((breakpoint) => {
            if (breakpoint === null) {
                return null;
            }
            else {
                return `d-${breakpoint}-none`;
            }
        }));
        this.backgroundColorClass$ = this.color$.pipe(map((color) => {
            switch (color) {
                case Color.light:
                case null:
                    return ['navbar-light'];
                default:
                    return ['navbar-dark', `bg-${Color[color]}`];
            }
        }));
        this.navClassList$ = combineLatest([this.expandClass$, this.backgroundColorClass$])
            .pipe(map(([expandClass, backgroundColorClass]) => {
            const result = [];
            return result.concat(expandClass ?? [], ...backgroundColorClass);
        }));
    }
    onWindowResize() {
        this.isResizing$.next(true);
        if (typeof window !== 'undefined') {
            this.windowWidth$.next(window.innerWidth);
        }
    }
    toggleExpanded() {
        this.isExpanded$.pipe(take(1)).subscribe((isExpanded) => {
            this.isExpanded$.next(!isExpanded);
        });
    }
    get color() {
        return this.color$.value;
    }
    set color(value) {
        this.color$.next(value);
    }
    get breakpoint() {
        return this.breakPoint$.value;
    }
    set breakpoint(value) {
        this.breakPoint$.next(value);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsNavbarComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.1.2", type: BsNavbarComponent, selector: "bs-navbar", inputs: { autoclose: "autoclose", color: "color", breakpoint: "breakpoint" }, host: { listeners: { "window:resize": "onWindowResize()" } }, viewQueries: [{ propertyName: "nav", first: true, predicate: ["nav"], descendants: true }], ngImport: i0, template: "<bs-container>\n    <nav #nav class=\"navbar position-fixed\" [class]=\"navClassList$ | async\" bsUserAgent bsNoNoscript>\n        <div class=\"container-fluid nav-wrapper\">\n            <div class=\"d-flex\" [class]=\"wAutoClass$ | async\" [class.w-100]=\"isSmallMode$ | async\">\n                <ng-content select=\"bs-navbar-brand\"></ng-content>\n                <div class=\"flex-end d-flex tw\" [class]=\"dNoneClass$ | async\">\n                    <button (click)=\"toggleExpanded()\" title=\"Expand/collapse menu\" class=\"align-self-center\" [class.navbar-toggler]=\"!expandButtonTemplate\" [class.bg-transparent]=\"expandButtonTemplate\" [class.shadow-none]=\"expandButtonTemplate\" [class.border-0]=\"expandButtonTemplate\" type=\"button\">\n                        <ng-container *ngTemplateOutlet=\"expandButtonTemplate ?? defaultExpandButton; context: { $implicit: (isExpanded$ | async) ? 'open' : 'closed' }\"></ng-container>\n                    </button>\n                </div>\n            </div>\n            <ng-content></ng-content>\n        </div>\n    </nav>\n</bs-container>\n\n<ng-template #defaultExpandButton>\n    <span class=\"navbar-toggler-icon\"></span>\n</ng-template>", styles: ["::ng-deep .dropup,::ng-deep .dropend,::ng-deep .dropdown,::ng-deep .dropstart,::ng-deep .dropup-center,::ng-deep .dropdown-center{position:relative}::ng-deep .dropdown-toggle{white-space:nowrap}::ng-deep .dropdown-toggle:after{display:inline-block;margin-left:.255em;vertical-align:.255em;content:\"\";border-top:.3em solid;border-right:.3em solid transparent;border-bottom:0;border-left:.3em solid transparent}::ng-deep .dropdown-toggle:empty:after{margin-left:0}::ng-deep .dropdown-menu{--bs-dropdown-zindex: 1000;--bs-dropdown-min-width: 10rem;--bs-dropdown-padding-x: 0;--bs-dropdown-padding-y: .5rem;--bs-dropdown-spacer: .125rem;--bs-dropdown-font-size: 1rem;--bs-dropdown-color: var(--bs-body-color);--bs-dropdown-bg: var(--bs-body-bg);--bs-dropdown-border-color: var(--bs-border-color-translucent);--bs-dropdown-border-radius: var(--bs-border-radius);--bs-dropdown-border-width: var(--bs-border-width);--bs-dropdown-inner-border-radius: calc(var(--bs-border-radius) - var(--bs-border-width));--bs-dropdown-divider-bg: var(--bs-border-color-translucent);--bs-dropdown-divider-margin-y: .5rem;--bs-dropdown-box-shadow: 0 .5rem 1rem rgba(0, 0, 0, .15);--bs-dropdown-link-color: var(--bs-body-color);--bs-dropdown-link-hover-color: var(--bs-body-color);--bs-dropdown-link-hover-bg: var(--bs-tertiary-bg);--bs-dropdown-link-active-color: #fff;--bs-dropdown-link-active-bg: #0d6efd;--bs-dropdown-link-disabled-color: var(--bs-tertiary-color);--bs-dropdown-item-padding-x: 1rem;--bs-dropdown-item-padding-y: .25rem;--bs-dropdown-header-color: #6c757d;--bs-dropdown-header-padding-x: 1rem;--bs-dropdown-header-padding-y: .5rem;position:absolute;z-index:var(--bs-dropdown-zindex);display:none;min-width:var(--bs-dropdown-min-width);padding:var(--bs-dropdown-padding-y) var(--bs-dropdown-padding-x);margin:0;font-size:var(--bs-dropdown-font-size);color:var(--bs-dropdown-color);text-align:left;list-style:none;background-color:var(--bs-dropdown-bg);background-clip:padding-box;border:var(--bs-dropdown-border-width) solid var(--bs-dropdown-border-color);border-radius:var(--bs-dropdown-border-radius)}::ng-deep .dropdown-menu[data-bs-popper]{top:100%;left:0;margin-top:var(--bs-dropdown-spacer)}::ng-deep .dropdown-menu-start{--bs-position: start}::ng-deep .dropdown-menu-start[data-bs-popper]{right:auto;left:0}::ng-deep .dropdown-menu-end{--bs-position: end}::ng-deep .dropdown-menu-end[data-bs-popper]{right:0;left:auto}@media (min-width: 576px){::ng-deep .dropdown-menu-sm-start{--bs-position: start}::ng-deep .dropdown-menu-sm-start[data-bs-popper]{right:auto;left:0}::ng-deep .dropdown-menu-sm-end{--bs-position: end}::ng-deep .dropdown-menu-sm-end[data-bs-popper]{right:0;left:auto}}@media (min-width: 768px){::ng-deep .dropdown-menu-md-start{--bs-position: start}::ng-deep .dropdown-menu-md-start[data-bs-popper]{right:auto;left:0}::ng-deep .dropdown-menu-md-end{--bs-position: end}::ng-deep .dropdown-menu-md-end[data-bs-popper]{right:0;left:auto}}@media (min-width: 992px){::ng-deep .dropdown-menu-lg-start{--bs-position: start}::ng-deep .dropdown-menu-lg-start[data-bs-popper]{right:auto;left:0}::ng-deep .dropdown-menu-lg-end{--bs-position: end}::ng-deep .dropdown-menu-lg-end[data-bs-popper]{right:0;left:auto}}@media (min-width: 1200px){::ng-deep .dropdown-menu-xl-start{--bs-position: start}::ng-deep .dropdown-menu-xl-start[data-bs-popper]{right:auto;left:0}::ng-deep .dropdown-menu-xl-end{--bs-position: end}::ng-deep .dropdown-menu-xl-end[data-bs-popper]{right:0;left:auto}}@media (min-width: 1400px){::ng-deep .dropdown-menu-xxl-start{--bs-position: start}::ng-deep .dropdown-menu-xxl-start[data-bs-popper]{right:auto;left:0}::ng-deep .dropdown-menu-xxl-end{--bs-position: end}::ng-deep .dropdown-menu-xxl-end[data-bs-popper]{right:0;left:auto}}::ng-deep .dropup .dropdown-menu[data-bs-popper]{top:auto;bottom:100%;margin-top:0;margin-bottom:var(--bs-dropdown-spacer)}::ng-deep .dropup .dropdown-toggle:after{display:inline-block;margin-left:.255em;vertical-align:.255em;content:\"\";border-top:0;border-right:.3em solid transparent;border-bottom:.3em solid;border-left:.3em solid transparent}::ng-deep .dropup .dropdown-toggle:empty:after{margin-left:0}::ng-deep .dropend .dropdown-menu[data-bs-popper]{top:0;right:auto;left:100%;margin-top:0;margin-left:var(--bs-dropdown-spacer)}::ng-deep .dropend .dropdown-toggle:after{display:inline-block;margin-left:.255em;vertical-align:.255em;content:\"\";border-top:.3em solid transparent;border-right:0;border-bottom:.3em solid transparent;border-left:.3em solid}::ng-deep .dropend .dropdown-toggle:empty:after{margin-left:0}::ng-deep .dropend .dropdown-toggle:after{vertical-align:0}::ng-deep .dropstart .dropdown-menu[data-bs-popper]{top:0;right:100%;left:auto;margin-top:0;margin-right:var(--bs-dropdown-spacer)}::ng-deep .dropstart .dropdown-toggle:after{display:inline-block;margin-left:.255em;vertical-align:.255em;content:\"\"}::ng-deep .dropstart .dropdown-toggle:after{display:none}::ng-deep .dropstart .dropdown-toggle:before{display:inline-block;margin-right:.255em;vertical-align:.255em;content:\"\";border-top:.3em solid transparent;border-right:.3em solid;border-bottom:.3em solid transparent}::ng-deep .dropstart .dropdown-toggle:empty:after{margin-left:0}::ng-deep .dropstart .dropdown-toggle:before{vertical-align:0}::ng-deep .dropdown-divider{height:0;margin:var(--bs-dropdown-divider-margin-y) 0;overflow:hidden;border-top:1px solid var(--bs-dropdown-divider-bg);opacity:1}::ng-deep .dropdown-item{display:block;width:100%;padding:var(--bs-dropdown-item-padding-y) var(--bs-dropdown-item-padding-x);clear:both;font-weight:400;color:var(--bs-dropdown-link-color);text-align:inherit;text-decoration:none;white-space:nowrap;background-color:transparent;border:0;border-radius:var(--bs-dropdown-item-border-radius, 0)}::ng-deep .dropdown-item:hover,::ng-deep .dropdown-item:focus{color:var(--bs-dropdown-link-hover-color);background-color:var(--bs-dropdown-link-hover-bg)}::ng-deep .dropdown-item.active,::ng-deep .dropdown-item:active{color:var(--bs-dropdown-link-active-color);text-decoration:none;background-color:var(--bs-dropdown-link-active-bg)}::ng-deep .dropdown-item.disabled,::ng-deep .dropdown-item:disabled{color:var(--bs-dropdown-link-disabled-color);pointer-events:none;background-color:transparent}::ng-deep .dropdown-menu.show{display:block}::ng-deep .dropdown-header{display:block;padding:var(--bs-dropdown-header-padding-y) var(--bs-dropdown-header-padding-x);margin-bottom:0;font-size:.875rem;color:var(--bs-dropdown-header-color);white-space:nowrap}::ng-deep .dropdown-item-text{display:block;padding:var(--bs-dropdown-item-padding-y) var(--bs-dropdown-item-padding-x);color:var(--bs-dropdown-link-color)}::ng-deep .dropdown-menu-dark{--bs-dropdown-color: #dee2e6;--bs-dropdown-bg: #343a40;--bs-dropdown-border-color: var(--bs-border-color-translucent);--bs-dropdown-box-shadow: ;--bs-dropdown-link-color: #dee2e6;--bs-dropdown-link-hover-color: #fff;--bs-dropdown-divider-bg: var(--bs-border-color-translucent);--bs-dropdown-link-hover-bg: rgba(255, 255, 255, .15);--bs-dropdown-link-active-color: #fff;--bs-dropdown-link-active-bg: #0d6efd;--bs-dropdown-link-disabled-color: #adb5bd;--bs-dropdown-header-color: #adb5bd}::ng-deep .nav{--bs-nav-link-padding-x: 1rem;--bs-nav-link-padding-y: .5rem;--bs-nav-link-font-weight: ;--bs-nav-link-color: var(--bs-link-color);--bs-nav-link-hover-color: var(--bs-link-hover-color);--bs-nav-link-disabled-color: var(--bs-secondary-color);display:flex;flex-wrap:wrap;padding-left:0;margin-bottom:0;list-style:none}::ng-deep .nav-link{display:block;padding:var(--bs-nav-link-padding-y) var(--bs-nav-link-padding-x);font-size:var(--bs-nav-link-font-size);font-weight:var(--bs-nav-link-font-weight);color:var(--bs-nav-link-color);text-decoration:none;background:none;border:0;transition:color .15s ease-in-out,background-color .15s ease-in-out,border-color .15s ease-in-out}@media (prefers-reduced-motion: reduce){::ng-deep .nav-link{transition:none}}::ng-deep .nav-link:hover,::ng-deep .nav-link:focus{color:var(--bs-nav-link-hover-color)}::ng-deep .nav-link:focus-visible{outline:0;box-shadow:0 0 0 .25rem #0d6efd40}::ng-deep .nav-link.disabled{color:var(--bs-nav-link-disabled-color);pointer-events:none;cursor:default}::ng-deep .nav-tabs{--bs-nav-tabs-border-width: var(--bs-border-width);--bs-nav-tabs-border-color: var(--bs-border-color);--bs-nav-tabs-border-radius: var(--bs-border-radius);--bs-nav-tabs-link-hover-border-color: var(--bs-secondary-bg) var(--bs-secondary-bg) var(--bs-border-color);--bs-nav-tabs-link-active-color: var(--bs-emphasis-color);--bs-nav-tabs-link-active-bg: var(--bs-body-bg);--bs-nav-tabs-link-active-border-color: var(--bs-border-color) var(--bs-border-color) var(--bs-body-bg);border-bottom:var(--bs-nav-tabs-border-width) solid var(--bs-nav-tabs-border-color)}::ng-deep .nav-tabs .nav-link{margin-bottom:calc(-1 * var(--bs-nav-tabs-border-width));border:var(--bs-nav-tabs-border-width) solid transparent;border-top-left-radius:var(--bs-nav-tabs-border-radius);border-top-right-radius:var(--bs-nav-tabs-border-radius)}::ng-deep .nav-tabs .nav-link:hover,::ng-deep .nav-tabs .nav-link:focus{isolation:isolate;border-color:var(--bs-nav-tabs-link-hover-border-color)}::ng-deep .nav-tabs .nav-link.disabled,::ng-deep .nav-tabs .nav-link:disabled{color:var(--bs-nav-link-disabled-color);background-color:transparent;border-color:transparent}::ng-deep .nav-tabs .nav-link.active,::ng-deep .nav-tabs .nav-item.show .nav-link{color:var(--bs-nav-tabs-link-active-color);background-color:var(--bs-nav-tabs-link-active-bg);border-color:var(--bs-nav-tabs-link-active-border-color)}::ng-deep .nav-tabs .dropdown-menu{margin-top:calc(-1 * var(--bs-nav-tabs-border-width));border-top-left-radius:0;border-top-right-radius:0}::ng-deep .nav-pills{--bs-nav-pills-border-radius: var(--bs-border-radius);--bs-nav-pills-link-active-color: #fff;--bs-nav-pills-link-active-bg: #0d6efd}::ng-deep .nav-pills .nav-link{border-radius:var(--bs-nav-pills-border-radius)}::ng-deep .nav-pills .nav-link:disabled{color:var(--bs-nav-link-disabled-color);background-color:transparent;border-color:transparent}::ng-deep .nav-pills .nav-link.active,::ng-deep .nav-pills .show>.nav-link{color:var(--bs-nav-pills-link-active-color);background-color:var(--bs-nav-pills-link-active-bg)}::ng-deep .nav-underline{--bs-nav-underline-gap: 1rem;--bs-nav-underline-border-width: .125rem;--bs-nav-underline-link-active-color: var(--bs-emphasis-color);gap:var(--bs-nav-underline-gap)}::ng-deep .nav-underline .nav-link{padding-right:0;padding-left:0;border-bottom:var(--bs-nav-underline-border-width) solid transparent}::ng-deep .nav-underline .nav-link:hover,::ng-deep .nav-underline .nav-link:focus{border-bottom-color:currentcolor}::ng-deep .nav-underline .nav-link.active,::ng-deep .nav-underline .show>.nav-link{font-weight:700;color:var(--bs-nav-underline-link-active-color);border-bottom-color:currentcolor}::ng-deep .nav-fill>.nav-link,::ng-deep .nav-fill .nav-item{flex:1 1 auto;text-align:center}::ng-deep .nav-justified>.nav-link,::ng-deep .nav-justified .nav-item{flex-basis:0;flex-grow:1;text-align:center}::ng-deep .nav-fill .nav-item .nav-link,::ng-deep .nav-justified .nav-item .nav-link{width:100%}::ng-deep .tab-content>.tab-pane{display:none}::ng-deep .tab-content>.active{display:block}::ng-deep .navbar{--bs-navbar-padding-x: 0;--bs-navbar-padding-y: .5rem;--bs-navbar-color: rgba(var(--bs-emphasis-color-rgb), .65);--bs-navbar-hover-color: rgba(var(--bs-emphasis-color-rgb), .8);--bs-navbar-disabled-color: rgba(var(--bs-emphasis-color-rgb), .3);--bs-navbar-active-color: rgba(var(--bs-emphasis-color-rgb), 1);--bs-navbar-brand-padding-y: .3125rem;--bs-navbar-brand-margin-end: 1rem;--bs-navbar-brand-font-size: 1.25rem;--bs-navbar-brand-color: rgba(var(--bs-emphasis-color-rgb), 1);--bs-navbar-brand-hover-color: rgba(var(--bs-emphasis-color-rgb), 1);--bs-navbar-nav-link-padding-x: .5rem;--bs-navbar-toggler-padding-y: .25rem;--bs-navbar-toggler-padding-x: .75rem;--bs-navbar-toggler-font-size: 1.25rem;--bs-navbar-toggler-icon-bg: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 30 30'%3e%3cpath stroke='rgba%2833, 37, 41, 0.75%29' stroke-linecap='round' stroke-miterlimit='10' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/%3e%3c/svg%3e\");--bs-navbar-toggler-border-color: rgba(var(--bs-emphasis-color-rgb), .15);--bs-navbar-toggler-border-radius: var(--bs-border-radius);--bs-navbar-toggler-focus-width: .25rem;--bs-navbar-toggler-transition: box-shadow .15s ease-in-out;position:relative;display:flex;flex-wrap:wrap;align-items:center;justify-content:space-between;padding:var(--bs-navbar-padding-y) var(--bs-navbar-padding-x)}::ng-deep .navbar>.container-xxl,::ng-deep .navbar>.container-xl,::ng-deep .navbar>.container-lg,::ng-deep .navbar>.container-md,::ng-deep .navbar>.container-sm,::ng-deep .navbar>.container,::ng-deep .navbar>.container-fluid{display:flex;flex-wrap:inherit;align-items:center;justify-content:space-between}::ng-deep .navbar-brand{padding-top:var(--bs-navbar-brand-padding-y);padding-bottom:var(--bs-navbar-brand-padding-y);margin-right:var(--bs-navbar-brand-margin-end);font-size:var(--bs-navbar-brand-font-size);color:var(--bs-navbar-brand-color);text-decoration:none;white-space:nowrap}::ng-deep .navbar-brand:hover,::ng-deep .navbar-brand:focus{color:var(--bs-navbar-brand-hover-color)}::ng-deep .navbar-nav{--bs-nav-link-padding-x: 0;--bs-nav-link-padding-y: .5rem;--bs-nav-link-font-weight: ;--bs-nav-link-color: var(--bs-navbar-color);--bs-nav-link-hover-color: var(--bs-navbar-hover-color);--bs-nav-link-disabled-color: var(--bs-navbar-disabled-color);display:flex;flex-direction:column;padding-left:0;margin-bottom:0;list-style:none}::ng-deep .navbar-nav .nav-link.active,::ng-deep .navbar-nav .nav-link.show{color:var(--bs-navbar-active-color)}::ng-deep .navbar-nav .dropdown-menu{position:static}::ng-deep .navbar-text{padding-top:.5rem;padding-bottom:.5rem;color:var(--bs-navbar-color)}::ng-deep .navbar-text a,::ng-deep .navbar-text a:hover,::ng-deep .navbar-text a:focus{color:var(--bs-navbar-active-color)}::ng-deep .navbar-collapse{flex-basis:100%;flex-grow:1;align-items:center}::ng-deep .navbar-toggler{padding:var(--bs-navbar-toggler-padding-y) var(--bs-navbar-toggler-padding-x);font-size:var(--bs-navbar-toggler-font-size);line-height:1;color:var(--bs-navbar-color);background-color:transparent;border:var(--bs-border-width) solid var(--bs-navbar-toggler-border-color);border-radius:var(--bs-navbar-toggler-border-radius);transition:var(--bs-navbar-toggler-transition)}@media (prefers-reduced-motion: reduce){::ng-deep .navbar-toggler{transition:none}}::ng-deep .navbar-toggler:hover{text-decoration:none}::ng-deep .navbar-toggler:focus{text-decoration:none;outline:0;box-shadow:0 0 0 var(--bs-navbar-toggler-focus-width)}::ng-deep .navbar-toggler-icon{display:inline-block;width:1.5em;height:1.5em;vertical-align:middle;background-image:var(--bs-navbar-toggler-icon-bg);background-repeat:no-repeat;background-position:center;background-size:100%}::ng-deep .navbar-nav-scroll{max-height:var(--bs-scroll-height, 75vh);overflow-y:auto}@media (min-width: 576px){::ng-deep .navbar-expand-sm{flex-wrap:nowrap;justify-content:flex-start}::ng-deep .navbar-expand-sm .navbar-nav{flex-direction:row}::ng-deep .navbar-expand-sm .navbar-nav .dropdown-menu{position:absolute}::ng-deep .navbar-expand-sm .navbar-nav .nav-link{padding-right:var(--bs-navbar-nav-link-padding-x);padding-left:var(--bs-navbar-nav-link-padding-x)}::ng-deep .navbar-expand-sm .navbar-nav-scroll{overflow:visible}::ng-deep .navbar-expand-sm .navbar-collapse{display:flex!important;flex-basis:auto}::ng-deep .navbar-expand-sm .navbar-toggler{display:none}::ng-deep .navbar-expand-sm .offcanvas{position:static;z-index:auto;flex-grow:1;width:auto!important;height:auto!important;visibility:visible!important;background-color:transparent!important;border:0!important;transform:none!important;transition:none}::ng-deep .navbar-expand-sm .offcanvas .offcanvas-header{display:none}::ng-deep .navbar-expand-sm .offcanvas .offcanvas-body{display:flex;flex-grow:0;padding:0;overflow-y:visible}}@media (min-width: 768px){::ng-deep .navbar-expand-md{flex-wrap:nowrap;justify-content:flex-start}::ng-deep .navbar-expand-md .navbar-nav{flex-direction:row}::ng-deep .navbar-expand-md .navbar-nav .dropdown-menu{position:absolute}::ng-deep .navbar-expand-md .navbar-nav .nav-link{padding-right:var(--bs-navbar-nav-link-padding-x);padding-left:var(--bs-navbar-nav-link-padding-x)}::ng-deep .navbar-expand-md .navbar-nav-scroll{overflow:visible}::ng-deep .navbar-expand-md .navbar-collapse{display:flex!important;flex-basis:auto}::ng-deep .navbar-expand-md .navbar-toggler{display:none}::ng-deep .navbar-expand-md .offcanvas{position:static;z-index:auto;flex-grow:1;width:auto!important;height:auto!important;visibility:visible!important;background-color:transparent!important;border:0!important;transform:none!important;transition:none}::ng-deep .navbar-expand-md .offcanvas .offcanvas-header{display:none}::ng-deep .navbar-expand-md .offcanvas .offcanvas-body{display:flex;flex-grow:0;padding:0;overflow-y:visible}}@media (min-width: 992px){::ng-deep .navbar-expand-lg{flex-wrap:nowrap;justify-content:flex-start}::ng-deep .navbar-expand-lg .navbar-nav{flex-direction:row}::ng-deep .navbar-expand-lg .navbar-nav .dropdown-menu{position:absolute}::ng-deep .navbar-expand-lg .navbar-nav .nav-link{padding-right:var(--bs-navbar-nav-link-padding-x);padding-left:var(--bs-navbar-nav-link-padding-x)}::ng-deep .navbar-expand-lg .navbar-nav-scroll{overflow:visible}::ng-deep .navbar-expand-lg .navbar-collapse{display:flex!important;flex-basis:auto}::ng-deep .navbar-expand-lg .navbar-toggler{display:none}::ng-deep .navbar-expand-lg .offcanvas{position:static;z-index:auto;flex-grow:1;width:auto!important;height:auto!important;visibility:visible!important;background-color:transparent!important;border:0!important;transform:none!important;transition:none}::ng-deep .navbar-expand-lg .offcanvas .offcanvas-header{display:none}::ng-deep .navbar-expand-lg .offcanvas .offcanvas-body{display:flex;flex-grow:0;padding:0;overflow-y:visible}}@media (min-width: 1200px){::ng-deep .navbar-expand-xl{flex-wrap:nowrap;justify-content:flex-start}::ng-deep .navbar-expand-xl .navbar-nav{flex-direction:row}::ng-deep .navbar-expand-xl .navbar-nav .dropdown-menu{position:absolute}::ng-deep .navbar-expand-xl .navbar-nav .nav-link{padding-right:var(--bs-navbar-nav-link-padding-x);padding-left:var(--bs-navbar-nav-link-padding-x)}::ng-deep .navbar-expand-xl .navbar-nav-scroll{overflow:visible}::ng-deep .navbar-expand-xl .navbar-collapse{display:flex!important;flex-basis:auto}::ng-deep .navbar-expand-xl .navbar-toggler{display:none}::ng-deep .navbar-expand-xl .offcanvas{position:static;z-index:auto;flex-grow:1;width:auto!important;height:auto!important;visibility:visible!important;background-color:transparent!important;border:0!important;transform:none!important;transition:none}::ng-deep .navbar-expand-xl .offcanvas .offcanvas-header{display:none}::ng-deep .navbar-expand-xl .offcanvas .offcanvas-body{display:flex;flex-grow:0;padding:0;overflow-y:visible}}@media (min-width: 1400px){::ng-deep .navbar-expand-xxl{flex-wrap:nowrap;justify-content:flex-start}::ng-deep .navbar-expand-xxl .navbar-nav{flex-direction:row}::ng-deep .navbar-expand-xxl .navbar-nav .dropdown-menu{position:absolute}::ng-deep .navbar-expand-xxl .navbar-nav .nav-link{padding-right:var(--bs-navbar-nav-link-padding-x);padding-left:var(--bs-navbar-nav-link-padding-x)}::ng-deep .navbar-expand-xxl .navbar-nav-scroll{overflow:visible}::ng-deep .navbar-expand-xxl .navbar-collapse{display:flex!important;flex-basis:auto}::ng-deep .navbar-expand-xxl .navbar-toggler{display:none}::ng-deep .navbar-expand-xxl .offcanvas{position:static;z-index:auto;flex-grow:1;width:auto!important;height:auto!important;visibility:visible!important;background-color:transparent!important;border:0!important;transform:none!important;transition:none}::ng-deep .navbar-expand-xxl .offcanvas .offcanvas-header{display:none}::ng-deep .navbar-expand-xxl .offcanvas .offcanvas-body{display:flex;flex-grow:0;padding:0;overflow-y:visible}}::ng-deep .navbar-expand{flex-wrap:nowrap;justify-content:flex-start}::ng-deep .navbar-expand .navbar-nav{flex-direction:row}::ng-deep .navbar-expand .navbar-nav .dropdown-menu{position:absolute}::ng-deep .navbar-expand .navbar-nav .nav-link{padding-right:var(--bs-navbar-nav-link-padding-x);padding-left:var(--bs-navbar-nav-link-padding-x)}::ng-deep .navbar-expand .navbar-nav-scroll{overflow:visible}::ng-deep .navbar-expand .navbar-collapse{display:flex!important;flex-basis:auto}::ng-deep .navbar-expand .navbar-toggler{display:none}::ng-deep .navbar-expand .offcanvas{position:static;z-index:auto;flex-grow:1;width:auto!important;height:auto!important;visibility:visible!important;background-color:transparent!important;border:0!important;transform:none!important;transition:none}::ng-deep .navbar-expand .offcanvas .offcanvas-header{display:none}::ng-deep .navbar-expand .offcanvas .offcanvas-body{display:flex;flex-grow:0;padding:0;overflow-y:visible}::ng-deep .navbar-dark,::ng-deep .navbar[data-bs-theme=dark]{--bs-navbar-color: rgba(255, 255, 255, .55);--bs-navbar-hover-color: rgba(255, 255, 255, .75);--bs-navbar-disabled-color: rgba(255, 255, 255, .25);--bs-navbar-active-color: #fff;--bs-navbar-brand-color: #fff;--bs-navbar-brand-hover-color: #fff;--bs-navbar-toggler-border-color: rgba(255, 255, 255, .1);--bs-navbar-toggler-icon-bg: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 30 30'%3e%3cpath stroke='rgba%28255, 255, 255, 0.55%29' stroke-linecap='round' stroke-miterlimit='10' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/%3e%3c/svg%3e\")}::ng-deep [data-bs-theme=dark] .navbar-toggler-icon{--bs-navbar-toggler-icon-bg: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 30 30'%3e%3cpath stroke='rgba%28255, 255, 255, 0.55%29' stroke-linecap='round' stroke-miterlimit='10' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/%3e%3c/svg%3e\")}::ng-deep .navbar{z-index:20!important}::ng-deep .navbar.noscript:not(:focus-within)>div>bs-navbar-nav>div.navbar-collapse{display:none}::ng-deep .navbar.noscript li.nav-item:focus-within>bs-navbar-dropdown>ul{display:block}::ng-deep .navbar.noscript li.nav-item:focus-within>bs-navbar-dropdown>ul li:has(a.dropdown-item):focus-within>bs-navbar-dropdown>ul{display:block}nav{left:0;top:0;right:0;z-index:10}@media (min-width: 768px){.mx-md-unset{margin-left:0!important;margin-right:0!important}.w-md-auto{width:auto!important}}.tw{margin:-.5rem 0}::ng-deep bs-navbar-nav{display:contents}@media (max-width: 575.98px){nav.navbar-expand-sm ::ng-deep div.navbar-collapse{overflow-y:hidden}nav.navbar-expand-sm.position-fixed{max-height:100%;overflow-y:scroll}nav.navbar-expand-sm.os-windows{margin-right:-17px}}@media (max-width: 767.98px){nav.navbar-expand-md ::ng-deep div.navbar-collapse{overflow-y:hidden}nav.navbar-expand-md.position-fixed{max-height:100%;overflow-y:scroll}nav.navbar-expand-md.os-windows{margin-right:-17px}}@media (max-width: 991.98px){nav.navbar-expand-lg ::ng-deep div.navbar-collapse{overflow-y:hidden}nav.navbar-expand-lg.position-fixed{max-height:100%;overflow-y:scroll}nav.navbar-expand-lg.os-windows{margin-right:-17px}}@media (max-width: 1199.98px){nav.navbar-expand-xl ::ng-deep div.navbar-collapse{overflow-y:hidden}nav.navbar-expand-xl.position-fixed{max-height:100%;overflow-y:scroll}nav.navbar-expand-xl.os-windows{margin-right:-17px}}@media (max-width: 1399.98px){nav.navbar-expand-xxl ::ng-deep div.navbar-collapse{overflow-y:hidden}nav.navbar-expand-xxl.position-fixed{max-height:100%;overflow-y:scroll}nav.navbar-expand-xxl.os-windows{margin-right:-17px}}.nav-wrapper ::ng-deep bs-navbar-nav>.navbar-collapse{justify-content:center}.nav-wrapper ::ng-deep bs-navbar-nav:first-of-type>.navbar-collapse{justify-content:flex-start}.nav-wrapper ::ng-deep bs-navbar-nav:last-of-type>.navbar-collapse{justify-content:flex-end}\n"], dependencies: [{ kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: i2.BsContainerComponent, selector: "bs-container" }, { kind: "directive", type: i3.BsUserAgentDirective, selector: "[bsUserAgent]", outputs: ["detected"] }, { kind: "directive", type: i4.BsNoNoscriptDirective, selector: "[bsNoNoscript]" }, { kind: "pipe", type: i1.AsyncPipe, name: "async" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsNavbarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'bs-navbar', template: "<bs-container>\n    <nav #nav class=\"navbar position-fixed\" [class]=\"navClassList$ | async\" bsUserAgent bsNoNoscript>\n        <div class=\"container-fluid nav-wrapper\">\n            <div class=\"d-flex\" [class]=\"wAutoClass$ | async\" [class.w-100]=\"isSmallMode$ | async\">\n                <ng-content select=\"bs-navbar-brand\"></ng-content>\n                <div class=\"flex-end d-flex tw\" [class]=\"dNoneClass$ | async\">\n                    <button (click)=\"toggleExpanded()\" title=\"Expand/collapse menu\" class=\"align-self-center\" [class.navbar-toggler]=\"!expandButtonTemplate\" [class.bg-transparent]=\"expandButtonTemplate\" [class.shadow-none]=\"expandButtonTemplate\" [class.border-0]=\"expandButtonTemplate\" type=\"button\">\n                        <ng-container *ngTemplateOutlet=\"expandButtonTemplate ?? defaultExpandButton; context: { $implicit: (isExpanded$ | async) ? 'open' : 'closed' }\"></ng-container>\n                    </button>\n                </div>\n            </div>\n            <ng-content></ng-content>\n        </div>\n    </nav>\n</bs-container>\n\n<ng-template #defaultExpandButton>\n    <span class=\"navbar-toggler-icon\"></span>\n</ng-template>", styles: ["::ng-deep .dropup,::ng-deep .dropend,::ng-deep .dropdown,::ng-deep .dropstart,::ng-deep .dropup-center,::ng-deep .dropdown-center{position:relative}::ng-deep .dropdown-toggle{white-space:nowrap}::ng-deep .dropdown-toggle:after{display:inline-block;margin-left:.255em;vertical-align:.255em;content:\"\";border-top:.3em solid;border-right:.3em solid transparent;border-bottom:0;border-left:.3em solid transparent}::ng-deep .dropdown-toggle:empty:after{margin-left:0}::ng-deep .dropdown-menu{--bs-dropdown-zindex: 1000;--bs-dropdown-min-width: 10rem;--bs-dropdown-padding-x: 0;--bs-dropdown-padding-y: .5rem;--bs-dropdown-spacer: .125rem;--bs-dropdown-font-size: 1rem;--bs-dropdown-color: var(--bs-body-color);--bs-dropdown-bg: var(--bs-body-bg);--bs-dropdown-border-color: var(--bs-border-color-translucent);--bs-dropdown-border-radius: var(--bs-border-radius);--bs-dropdown-border-width: var(--bs-border-width);--bs-dropdown-inner-border-radius: calc(var(--bs-border-radius) - var(--bs-border-width));--bs-dropdown-divider-bg: var(--bs-border-color-translucent);--bs-dropdown-divider-margin-y: .5rem;--bs-dropdown-box-shadow: 0 .5rem 1rem rgba(0, 0, 0, .15);--bs-dropdown-link-color: var(--bs-body-color);--bs-dropdown-link-hover-color: var(--bs-body-color);--bs-dropdown-link-hover-bg: var(--bs-tertiary-bg);--bs-dropdown-link-active-color: #fff;--bs-dropdown-link-active-bg: #0d6efd;--bs-dropdown-link-disabled-color: var(--bs-tertiary-color);--bs-dropdown-item-padding-x: 1rem;--bs-dropdown-item-padding-y: .25rem;--bs-dropdown-header-color: #6c757d;--bs-dropdown-header-padding-x: 1rem;--bs-dropdown-header-padding-y: .5rem;position:absolute;z-index:var(--bs-dropdown-zindex);display:none;min-width:var(--bs-dropdown-min-width);padding:var(--bs-dropdown-padding-y) var(--bs-dropdown-padding-x);margin:0;font-size:var(--bs-dropdown-font-size);color:var(--bs-dropdown-color);text-align:left;list-style:none;background-color:var(--bs-dropdown-bg);background-clip:padding-box;border:var(--bs-dropdown-border-width) solid var(--bs-dropdown-border-color);border-radius:var(--bs-dropdown-border-radius)}::ng-deep .dropdown-menu[data-bs-popper]{top:100%;left:0;margin-top:var(--bs-dropdown-spacer)}::ng-deep .dropdown-menu-start{--bs-position: start}::ng-deep .dropdown-menu-start[data-bs-popper]{right:auto;left:0}::ng-deep .dropdown-menu-end{--bs-position: end}::ng-deep .dropdown-menu-end[data-bs-popper]{right:0;left:auto}@media (min-width: 576px){::ng-deep .dropdown-menu-sm-start{--bs-position: start}::ng-deep .dropdown-menu-sm-start[data-bs-popper]{right:auto;left:0}::ng-deep .dropdown-menu-sm-end{--bs-position: end}::ng-deep .dropdown-menu-sm-end[data-bs-popper]{right:0;left:auto}}@media (min-width: 768px){::ng-deep .dropdown-menu-md-start{--bs-position: start}::ng-deep .dropdown-menu-md-start[data-bs-popper]{right:auto;left:0}::ng-deep .dropdown-menu-md-end{--bs-position: end}::ng-deep .dropdown-menu-md-end[data-bs-popper]{right:0;left:auto}}@media (min-width: 992px){::ng-deep .dropdown-menu-lg-start{--bs-position: start}::ng-deep .dropdown-menu-lg-start[data-bs-popper]{right:auto;left:0}::ng-deep .dropdown-menu-lg-end{--bs-position: end}::ng-deep .dropdown-menu-lg-end[data-bs-popper]{right:0;left:auto}}@media (min-width: 1200px){::ng-deep .dropdown-menu-xl-start{--bs-position: start}::ng-deep .dropdown-menu-xl-start[data-bs-popper]{right:auto;left:0}::ng-deep .dropdown-menu-xl-end{--bs-position: end}::ng-deep .dropdown-menu-xl-end[data-bs-popper]{right:0;left:auto}}@media (min-width: 1400px){::ng-deep .dropdown-menu-xxl-start{--bs-position: start}::ng-deep .dropdown-menu-xxl-start[data-bs-popper]{right:auto;left:0}::ng-deep .dropdown-menu-xxl-end{--bs-position: end}::ng-deep .dropdown-menu-xxl-end[data-bs-popper]{right:0;left:auto}}::ng-deep .dropup .dropdown-menu[data-bs-popper]{top:auto;bottom:100%;margin-top:0;margin-bottom:var(--bs-dropdown-spacer)}::ng-deep .dropup .dropdown-toggle:after{display:inline-block;margin-left:.255em;vertical-align:.255em;content:\"\";border-top:0;border-right:.3em solid transparent;border-bottom:.3em solid;border-left:.3em solid transparent}::ng-deep .dropup .dropdown-toggle:empty:after{margin-left:0}::ng-deep .dropend .dropdown-menu[data-bs-popper]{top:0;right:auto;left:100%;margin-top:0;margin-left:var(--bs-dropdown-spacer)}::ng-deep .dropend .dropdown-toggle:after{display:inline-block;margin-left:.255em;vertical-align:.255em;content:\"\";border-top:.3em solid transparent;border-right:0;border-bottom:.3em solid transparent;border-left:.3em solid}::ng-deep .dropend .dropdown-toggle:empty:after{margin-left:0}::ng-deep .dropend .dropdown-toggle:after{vertical-align:0}::ng-deep .dropstart .dropdown-menu[data-bs-popper]{top:0;right:100%;left:auto;margin-top:0;margin-right:var(--bs-dropdown-spacer)}::ng-deep .dropstart .dropdown-toggle:after{display:inline-block;margin-left:.255em;vertical-align:.255em;content:\"\"}::ng-deep .dropstart .dropdown-toggle:after{display:none}::ng-deep .dropstart .dropdown-toggle:before{display:inline-block;margin-right:.255em;vertical-align:.255em;content:\"\";border-top:.3em solid transparent;border-right:.3em solid;border-bottom:.3em solid transparent}::ng-deep .dropstart .dropdown-toggle:empty:after{margin-left:0}::ng-deep .dropstart .dropdown-toggle:before{vertical-align:0}::ng-deep .dropdown-divider{height:0;margin:var(--bs-dropdown-divider-margin-y) 0;overflow:hidden;border-top:1px solid var(--bs-dropdown-divider-bg);opacity:1}::ng-deep .dropdown-item{display:block;width:100%;padding:var(--bs-dropdown-item-padding-y) var(--bs-dropdown-item-padding-x);clear:both;font-weight:400;color:var(--bs-dropdown-link-color);text-align:inherit;text-decoration:none;white-space:nowrap;background-color:transparent;border:0;border-radius:var(--bs-dropdown-item-border-radius, 0)}::ng-deep .dropdown-item:hover,::ng-deep .dropdown-item:focus{color:var(--bs-dropdown-link-hover-color);background-color:var(--bs-dropdown-link-hover-bg)}::ng-deep .dropdown-item.active,::ng-deep .dropdown-item:active{color:var(--bs-dropdown-link-active-color);text-decoration:none;background-color:var(--bs-dropdown-link-active-bg)}::ng-deep .dropdown-item.disabled,::ng-deep .dropdown-item:disabled{color:var(--bs-dropdown-link-disabled-color);pointer-events:none;background-color:transparent}::ng-deep .dropdown-menu.show{display:block}::ng-deep .dropdown-header{display:block;padding:var(--bs-dropdown-header-padding-y) var(--bs-dropdown-header-padding-x);margin-bottom:0;font-size:.875rem;color:var(--bs-dropdown-header-color);white-space:nowrap}::ng-deep .dropdown-item-text{display:block;padding:var(--bs-dropdown-item-padding-y) var(--bs-dropdown-item-padding-x);color:var(--bs-dropdown-link-color)}::ng-deep .dropdown-menu-dark{--bs-dropdown-color: #dee2e6;--bs-dropdown-bg: #343a40;--bs-dropdown-border-color: var(--bs-border-color-translucent);--bs-dropdown-box-shadow: ;--bs-dropdown-link-color: #dee2e6;--bs-dropdown-link-hover-color: #fff;--bs-dropdown-divider-bg: var(--bs-border-color-translucent);--bs-dropdown-link-hover-bg: rgba(255, 255, 255, .15);--bs-dropdown-link-active-color: #fff;--bs-dropdown-link-active-bg: #0d6efd;--bs-dropdown-link-disabled-color: #adb5bd;--bs-dropdown-header-color: #adb5bd}::ng-deep .nav{--bs-nav-link-padding-x: 1rem;--bs-nav-link-padding-y: .5rem;--bs-nav-link-font-weight: ;--bs-nav-link-color: var(--bs-link-color);--bs-nav-link-hover-color: var(--bs-link-hover-color);--bs-nav-link-disabled-color: var(--bs-secondary-color);display:flex;flex-wrap:wrap;padding-left:0;margin-bottom:0;list-style:none}::ng-deep .nav-link{display:block;padding:var(--bs-nav-link-padding-y) var(--bs-nav-link-padding-x);font-size:var(--bs-nav-link-font-size);font-weight:var(--bs-nav-link-font-weight);color:var(--bs-nav-link-color);text-decoration:none;background:none;border:0;transition:color .15s ease-in-out,background-color .15s ease-in-out,border-color .15s ease-in-out}@media (prefers-reduced-motion: reduce){::ng-deep .nav-link{transition:none}}::ng-deep .nav-link:hover,::ng-deep .nav-link:focus{color:var(--bs-nav-link-hover-color)}::ng-deep .nav-link:focus-visible{outline:0;box-shadow:0 0 0 .25rem #0d6efd40}::ng-deep .nav-link.disabled{color:var(--bs-nav-link-disabled-color);pointer-events:none;cursor:default}::ng-deep .nav-tabs{--bs-nav-tabs-border-width: var(--bs-border-width);--bs-nav-tabs-border-color: var(--bs-border-color);--bs-nav-tabs-border-radius: var(--bs-border-radius);--bs-nav-tabs-link-hover-border-color: var(--bs-secondary-bg) var(--bs-secondary-bg) var(--bs-border-color);--bs-nav-tabs-link-active-color: var(--bs-emphasis-color);--bs-nav-tabs-link-active-bg: var(--bs-body-bg);--bs-nav-tabs-link-active-border-color: var(--bs-border-color) var(--bs-border-color) var(--bs-body-bg);border-bottom:var(--bs-nav-tabs-border-width) solid var(--bs-nav-tabs-border-color)}::ng-deep .nav-tabs .nav-link{margin-bottom:calc(-1 * var(--bs-nav-tabs-border-width));border:var(--bs-nav-tabs-border-width) solid transparent;border-top-left-radius:var(--bs-nav-tabs-border-radius);border-top-right-radius:var(--bs-nav-tabs-border-radius)}::ng-deep .nav-tabs .nav-link:hover,::ng-deep .nav-tabs .nav-link:focus{isolation:isolate;border-color:var(--bs-nav-tabs-link-hover-border-color)}::ng-deep .nav-tabs .nav-link.disabled,::ng-deep .nav-tabs .nav-link:disabled{color:var(--bs-nav-link-disabled-color);background-color:transparent;border-color:transparent}::ng-deep .nav-tabs .nav-link.active,::ng-deep .nav-tabs .nav-item.show .nav-link{color:var(--bs-nav-tabs-link-active-color);background-color:var(--bs-nav-tabs-link-active-bg);border-color:var(--bs-nav-tabs-link-active-border-color)}::ng-deep .nav-tabs .dropdown-menu{margin-top:calc(-1 * var(--bs-nav-tabs-border-width));border-top-left-radius:0;border-top-right-radius:0}::ng-deep .nav-pills{--bs-nav-pills-border-radius: var(--bs-border-radius);--bs-nav-pills-link-active-color: #fff;--bs-nav-pills-link-active-bg: #0d6efd}::ng-deep .nav-pills .nav-link{border-radius:var(--bs-nav-pills-border-radius)}::ng-deep .nav-pills .nav-link:disabled{color:var(--bs-nav-link-disabled-color);background-color:transparent;border-color:transparent}::ng-deep .nav-pills .nav-link.active,::ng-deep .nav-pills .show>.nav-link{color:var(--bs-nav-pills-link-active-color);background-color:var(--bs-nav-pills-link-active-bg)}::ng-deep .nav-underline{--bs-nav-underline-gap: 1rem;--bs-nav-underline-border-width: .125rem;--bs-nav-underline-link-active-color: var(--bs-emphasis-color);gap:var(--bs-nav-underline-gap)}::ng-deep .nav-underline .nav-link{padding-right:0;padding-left:0;border-bottom:var(--bs-nav-underline-border-width) solid transparent}::ng-deep .nav-underline .nav-link:hover,::ng-deep .nav-underline .nav-link:focus{border-bottom-color:currentcolor}::ng-deep .nav-underline .nav-link.active,::ng-deep .nav-underline .show>.nav-link{font-weight:700;color:var(--bs-nav-underline-link-active-color);border-bottom-color:currentcolor}::ng-deep .nav-fill>.nav-link,::ng-deep .nav-fill .nav-item{flex:1 1 auto;text-align:center}::ng-deep .nav-justified>.nav-link,::ng-deep .nav-justified .nav-item{flex-basis:0;flex-grow:1;text-align:center}::ng-deep .nav-fill .nav-item .nav-link,::ng-deep .nav-justified .nav-item .nav-link{width:100%}::ng-deep .tab-content>.tab-pane{display:none}::ng-deep .tab-content>.active{display:block}::ng-deep .navbar{--bs-navbar-padding-x: 0;--bs-navbar-padding-y: .5rem;--bs-navbar-color: rgba(var(--bs-emphasis-color-rgb), .65);--bs-navbar-hover-color: rgba(var(--bs-emphasis-color-rgb), .8);--bs-navbar-disabled-color: rgba(var(--bs-emphasis-color-rgb), .3);--bs-navbar-active-color: rgba(var(--bs-emphasis-color-rgb), 1);--bs-navbar-brand-padding-y: .3125rem;--bs-navbar-brand-margin-end: 1rem;--bs-navbar-brand-font-size: 1.25rem;--bs-navbar-brand-color: rgba(var(--bs-emphasis-color-rgb), 1);--bs-navbar-brand-hover-color: rgba(var(--bs-emphasis-color-rgb), 1);--bs-navbar-nav-link-padding-x: .5rem;--bs-navbar-toggler-padding-y: .25rem;--bs-navbar-toggler-padding-x: .75rem;--bs-navbar-toggler-font-size: 1.25rem;--bs-navbar-toggler-icon-bg: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 30 30'%3e%3cpath stroke='rgba%2833, 37, 41, 0.75%29' stroke-linecap='round' stroke-miterlimit='10' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/%3e%3c/svg%3e\");--bs-navbar-toggler-border-color: rgba(var(--bs-emphasis-color-rgb), .15);--bs-navbar-toggler-border-radius: var(--bs-border-radius);--bs-navbar-toggler-focus-width: .25rem;--bs-navbar-toggler-transition: box-shadow .15s ease-in-out;position:relative;display:flex;flex-wrap:wrap;align-items:center;justify-content:space-between;padding:var(--bs-navbar-padding-y) var(--bs-navbar-padding-x)}::ng-deep .navbar>.container-xxl,::ng-deep .navbar>.container-xl,::ng-deep .navbar>.container-lg,::ng-deep .navbar>.container-md,::ng-deep .navbar>.container-sm,::ng-deep .navbar>.container,::ng-deep .navbar>.container-fluid{display:flex;flex-wrap:inherit;align-items:center;justify-content:space-between}::ng-deep .navbar-brand{padding-top:var(--bs-navbar-brand-padding-y);padding-bottom:var(--bs-navbar-brand-padding-y);margin-right:var(--bs-navbar-brand-margin-end);font-size:var(--bs-navbar-brand-font-size);color:var(--bs-navbar-brand-color);text-decoration:none;white-space:nowrap}::ng-deep .navbar-brand:hover,::ng-deep .navbar-brand:focus{color:var(--bs-navbar-brand-hover-color)}::ng-deep .navbar-nav{--bs-nav-link-padding-x: 0;--bs-nav-link-padding-y: .5rem;--bs-nav-link-font-weight: ;--bs-nav-link-color: var(--bs-navbar-color);--bs-nav-link-hover-color: var(--bs-navbar-hover-color);--bs-nav-link-disabled-color: var(--bs-navbar-disabled-color);display:flex;flex-direction:column;padding-left:0;margin-bottom:0;list-style:none}::ng-deep .navbar-nav .nav-link.active,::ng-deep .navbar-nav .nav-link.show{color:var(--bs-navbar-active-color)}::ng-deep .navbar-nav .dropdown-menu{position:static}::ng-deep .navbar-text{padding-top:.5rem;padding-bottom:.5rem;color:var(--bs-navbar-color)}::ng-deep .navbar-text a,::ng-deep .navbar-text a:hover,::ng-deep .navbar-text a:focus{color:var(--bs-navbar-active-color)}::ng-deep .navbar-collapse{flex-basis:100%;flex-grow:1;align-items:center}::ng-deep .navbar-toggler{padding:var(--bs-navbar-toggler-padding-y) var(--bs-navbar-toggler-padding-x);font-size:var(--bs-navbar-toggler-font-size);line-height:1;color:var(--bs-navbar-color);background-color:transparent;border:var(--bs-border-width) solid var(--bs-navbar-toggler-border-color);border-radius:var(--bs-navbar-toggler-border-radius);transition:var(--bs-navbar-toggler-transition)}@media (prefers-reduced-motion: reduce){::ng-deep .navbar-toggler{transition:none}}::ng-deep .navbar-toggler:hover{text-decoration:none}::ng-deep .navbar-toggler:focus{text-decoration:none;outline:0;box-shadow:0 0 0 var(--bs-navbar-toggler-focus-width)}::ng-deep .navbar-toggler-icon{display:inline-block;width:1.5em;height:1.5em;vertical-align:middle;background-image:var(--bs-navbar-toggler-icon-bg);background-repeat:no-repeat;background-position:center;background-size:100%}::ng-deep .navbar-nav-scroll{max-height:var(--bs-scroll-height, 75vh);overflow-y:auto}@media (min-width: 576px){::ng-deep .navbar-expand-sm{flex-wrap:nowrap;justify-content:flex-start}::ng-deep .navbar-expand-sm .navbar-nav{flex-direction:row}::ng-deep .navbar-expand-sm .navbar-nav .dropdown-menu{position:absolute}::ng-deep .navbar-expand-sm .navbar-nav .nav-link{padding-right:var(--bs-navbar-nav-link-padding-x);padding-left:var(--bs-navbar-nav-link-padding-x)}::ng-deep .navbar-expand-sm .navbar-nav-scroll{overflow:visible}::ng-deep .navbar-expand-sm .navbar-collapse{display:flex!important;flex-basis:auto}::ng-deep .navbar-expand-sm .navbar-toggler{display:none}::ng-deep .navbar-expand-sm .offcanvas{position:static;z-index:auto;flex-grow:1;width:auto!important;height:auto!important;visibility:visible!important;background-color:transparent!important;border:0!important;transform:none!important;transition:none}::ng-deep .navbar-expand-sm .offcanvas .offcanvas-header{display:none}::ng-deep .navbar-expand-sm .offcanvas .offcanvas-body{display:flex;flex-grow:0;padding:0;overflow-y:visible}}@media (min-width: 768px){::ng-deep .navbar-expand-md{flex-wrap:nowrap;justify-content:flex-start}::ng-deep .navbar-expand-md .navbar-nav{flex-direction:row}::ng-deep .navbar-expand-md .navbar-nav .dropdown-menu{position:absolute}::ng-deep .navbar-expand-md .navbar-nav .nav-link{padding-right:var(--bs-navbar-nav-link-padding-x);padding-left:var(--bs-navbar-nav-link-padding-x)}::ng-deep .navbar-expand-md .navbar-nav-scroll{overflow:visible}::ng-deep .navbar-expand-md .navbar-collapse{display:flex!important;flex-basis:auto}::ng-deep .navbar-expand-md .navbar-toggler{display:none}::ng-deep .navbar-expand-md .offcanvas{position:static;z-index:auto;flex-grow:1;width:auto!important;height:auto!important;visibility:visible!important;background-color:transparent!important;border:0!important;transform:none!important;transition:none}::ng-deep .navbar-expand-md .offcanvas .offcanvas-header{display:none}::ng-deep .navbar-expand-md .offcanvas .offcanvas-body{display:flex;flex-grow:0;padding:0;overflow-y:visible}}@media (min-width: 992px){::ng-deep .navbar-expand-lg{flex-wrap:nowrap;justify-content:flex-start}::ng-deep .navbar-expand-lg .navbar-nav{flex-direction:row}::ng-deep .navbar-expand-lg .navbar-nav .dropdown-menu{position:absolute}::ng-deep .navbar-expand-lg .navbar-nav .nav-link{padding-right:var(--bs-navbar-nav-link-padding-x);padding-left:var(--bs-navbar-nav-link-padding-x)}::ng-deep .navbar-expand-lg .navbar-nav-scroll{overflow:visible}::ng-deep .navbar-expand-lg .navbar-collapse{display:flex!important;flex-basis:auto}::ng-deep .navbar-expand-lg .navbar-toggler{display:none}::ng-deep .navbar-expand-lg .offcanvas{position:static;z-index:auto;flex-grow:1;width:auto!important;height:auto!important;visibility:visible!important;background-color:transparent!important;border:0!important;transform:none!important;transition:none}::ng-deep .navbar-expand-lg .offcanvas .offcanvas-header{display:none}::ng-deep .navbar-expand-lg .offcanvas .offcanvas-body{display:flex;flex-grow:0;padding:0;overflow-y:visible}}@media (min-width: 1200px){::ng-deep .navbar-expand-xl{flex-wrap:nowrap;justify-content:flex-start}::ng-deep .navbar-expand-xl .navbar-nav{flex-direction:row}::ng-deep .navbar-expand-xl .navbar-nav .dropdown-menu{position:absolute}::ng-deep .navbar-expand-xl .navbar-nav .nav-link{padding-right:var(--bs-navbar-nav-link-padding-x);padding-left:var(--bs-navbar-nav-link-padding-x)}::ng-deep .navbar-expand-xl .navbar-nav-scroll{overflow:visible}::ng-deep .navbar-expand-xl .navbar-collapse{display:flex!important;flex-basis:auto}::ng-deep .navbar-expand-xl .navbar-toggler{display:none}::ng-deep .navbar-expand-xl .offcanvas{position:static;z-index:auto;flex-grow:1;width:auto!important;height:auto!important;visibility:visible!important;background-color:transparent!important;border:0!important;transform:none!important;transition:none}::ng-deep .navbar-expand-xl .offcanvas .offcanvas-header{display:none}::ng-deep .navbar-expand-xl .offcanvas .offcanvas-body{display:flex;flex-grow:0;padding:0;overflow-y:visible}}@media (min-width: 1400px){::ng-deep .navbar-expand-xxl{flex-wrap:nowrap;justify-content:flex-start}::ng-deep .navbar-expand-xxl .navbar-nav{flex-direction:row}::ng-deep .navbar-expand-xxl .navbar-nav .dropdown-menu{position:absolute}::ng-deep .navbar-expand-xxl .navbar-nav .nav-link{padding-right:var(--bs-navbar-nav-link-padding-x);padding-left:var(--bs-navbar-nav-link-padding-x)}::ng-deep .navbar-expand-xxl .navbar-nav-scroll{overflow:visible}::ng-deep .navbar-expand-xxl .navbar-collapse{display:flex!important;flex-basis:auto}::ng-deep .navbar-expand-xxl .navbar-toggler{display:none}::ng-deep .navbar-expand-xxl .offcanvas{position:static;z-index:auto;flex-grow:1;width:auto!important;height:auto!important;visibility:visible!important;background-color:transparent!important;border:0!important;transform:none!important;transition:none}::ng-deep .navbar-expand-xxl .offcanvas .offcanvas-header{display:none}::ng-deep .navbar-expand-xxl .offcanvas .offcanvas-body{display:flex;flex-grow:0;padding:0;overflow-y:visible}}::ng-deep .navbar-expand{flex-wrap:nowrap;justify-content:flex-start}::ng-deep .navbar-expand .navbar-nav{flex-direction:row}::ng-deep .navbar-expand .navbar-nav .dropdown-menu{position:absolute}::ng-deep .navbar-expand .navbar-nav .nav-link{padding-right:var(--bs-navbar-nav-link-padding-x);padding-left:var(--bs-navbar-nav-link-padding-x)}::ng-deep .navbar-expand .navbar-nav-scroll{overflow:visible}::ng-deep .navbar-expand .navbar-collapse{display:flex!important;flex-basis:auto}::ng-deep .navbar-expand .navbar-toggler{display:none}::ng-deep .navbar-expand .offcanvas{position:static;z-index:auto;flex-grow:1;width:auto!important;height:auto!important;visibility:visible!important;background-color:transparent!important;border:0!important;transform:none!important;transition:none}::ng-deep .navbar-expand .offcanvas .offcanvas-header{display:none}::ng-deep .navbar-expand .offcanvas .offcanvas-body{display:flex;flex-grow:0;padding:0;overflow-y:visible}::ng-deep .navbar-dark,::ng-deep .navbar[data-bs-theme=dark]{--bs-navbar-color: rgba(255, 255, 255, .55);--bs-navbar-hover-color: rgba(255, 255, 255, .75);--bs-navbar-disabled-color: rgba(255, 255, 255, .25);--bs-navbar-active-color: #fff;--bs-navbar-brand-color: #fff;--bs-navbar-brand-hover-color: #fff;--bs-navbar-toggler-border-color: rgba(255, 255, 255, .1);--bs-navbar-toggler-icon-bg: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 30 30'%3e%3cpath stroke='rgba%28255, 255, 255, 0.55%29' stroke-linecap='round' stroke-miterlimit='10' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/%3e%3c/svg%3e\")}::ng-deep [data-bs-theme=dark] .navbar-toggler-icon{--bs-navbar-toggler-icon-bg: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 30 30'%3e%3cpath stroke='rgba%28255, 255, 255, 0.55%29' stroke-linecap='round' stroke-miterlimit='10' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/%3e%3c/svg%3e\")}::ng-deep .navbar{z-index:20!important}::ng-deep .navbar.noscript:not(:focus-within)>div>bs-navbar-nav>div.navbar-collapse{display:none}::ng-deep .navbar.noscript li.nav-item:focus-within>bs-navbar-dropdown>ul{display:block}::ng-deep .navbar.noscript li.nav-item:focus-within>bs-navbar-dropdown>ul li:has(a.dropdown-item):focus-within>bs-navbar-dropdown>ul{display:block}nav{left:0;top:0;right:0;z-index:10}@media (min-width: 768px){.mx-md-unset{margin-left:0!important;margin-right:0!important}.w-md-auto{width:auto!important}}.tw{margin:-.5rem 0}::ng-deep bs-navbar-nav{display:contents}@media (max-width: 575.98px){nav.navbar-expand-sm ::ng-deep div.navbar-collapse{overflow-y:hidden}nav.navbar-expand-sm.position-fixed{max-height:100%;overflow-y:scroll}nav.navbar-expand-sm.os-windows{margin-right:-17px}}@media (max-width: 767.98px){nav.navbar-expand-md ::ng-deep div.navbar-collapse{overflow-y:hidden}nav.navbar-expand-md.position-fixed{max-height:100%;overflow-y:scroll}nav.navbar-expand-md.os-windows{margin-right:-17px}}@media (max-width: 991.98px){nav.navbar-expand-lg ::ng-deep div.navbar-collapse{overflow-y:hidden}nav.navbar-expand-lg.position-fixed{max-height:100%;overflow-y:scroll}nav.navbar-expand-lg.os-windows{margin-right:-17px}}@media (max-width: 1199.98px){nav.navbar-expand-xl ::ng-deep div.navbar-collapse{overflow-y:hidden}nav.navbar-expand-xl.position-fixed{max-height:100%;overflow-y:scroll}nav.navbar-expand-xl.os-windows{margin-right:-17px}}@media (max-width: 1399.98px){nav.navbar-expand-xxl ::ng-deep div.navbar-collapse{overflow-y:hidden}nav.navbar-expand-xxl.position-fixed{max-height:100%;overflow-y:scroll}nav.navbar-expand-xxl.os-windows{margin-right:-17px}}.nav-wrapper ::ng-deep bs-navbar-nav>.navbar-collapse{justify-content:center}.nav-wrapper ::ng-deep bs-navbar-nav:first-of-type>.navbar-collapse{justify-content:flex-start}.nav-wrapper ::ng-deep bs-navbar-nav:last-of-type>.navbar-collapse{justify-content:flex-end}\n"] }]
        }], ctorParameters: function () { return []; }, propDecorators: { onWindowResize: [{
                type: HostListener,
                args: ['window:resize']
            }], nav: [{
                type: ViewChild,
                args: ['nav']
            }], autoclose: [{
                type: Input
            }], color: [{
                type: Input
            }], breakpoint: [{
                type: Input
            }] } });

class BsNavbarNavComponent {
    constructor(bsNavbar) {
        this.collapse$ = new BehaviorSubject(true);
        this.windowWidth$ = new BehaviorSubject(null);
        this.isResizing$ = new BehaviorSubject(false);
        this.bsNavbar = bsNavbar;
        this.showNavs$ = combineLatest([this.bsNavbar.isExpanded$, this.bsNavbar.expandAt$, this.windowWidth$])
            .pipe(filter(([isExpanded, expandAt, windowWidth]) => {
            return windowWidth !== null;
        }))
            .pipe(map(([isExpanded, expandAt, windowWidth]) => {
            if (windowWidth === null) {
                throw 'windowWidth should not be null here';
            }
            else if (expandAt === null) {
                return isExpanded;
            }
            else if (windowWidth >= expandAt) {
                return true;
            }
            else {
                return isExpanded;
            }
        }));
        this.windowWidth$
            .pipe(debounceTime(300), takeUntilDestroyed())
            .subscribe(() => this.isResizing$.next(false));
        this.onWindowResize();
    }
    //#region collapse
    set collapse(value) {
        this.collapse$.next(value);
    }
    get collapse() {
        return this.collapse$.value;
    }
    //#endregion
    onWindowResize() {
        this.isResizing$.next(true);
        if (typeof window !== 'undefined') {
            this.windowWidth$.next(window.innerWidth);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsNavbarNavComponent, deps: [{ token: BsNavbarComponent }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.1.2", type: BsNavbarNavComponent, selector: "bs-navbar-nav", inputs: { collapse: "collapse" }, host: { listeners: { "window:resize": "onWindowResize()" } }, ngImport: i0, template: "<div class=\"navbar-collapse w-100 show\" [class.collapse]=\"collapse$ | async\" [@slideUpDown]=\"showNavs$ | async\" [@.disabled]=\"isResizing$ | async\">\n    <ul class=\"navbar-nav mr-auto\">\n        <ng-content></ng-content>\n    </ul>\n</div>", styles: [":host{margin-right:auto}\n"], dependencies: [{ kind: "pipe", type: i1.AsyncPipe, name: "async" }], animations: [SlideUpDownAnimation] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsNavbarNavComponent, decorators: [{
            type: Component,
            args: [{ selector: 'bs-navbar-nav', animations: [SlideUpDownAnimation], template: "<div class=\"navbar-collapse w-100 show\" [class.collapse]=\"collapse$ | async\" [@slideUpDown]=\"showNavs$ | async\" [@.disabled]=\"isResizing$ | async\">\n    <ul class=\"navbar-nav mr-auto\">\n        <ng-content></ng-content>\n    </ul>\n</div>", styles: [":host{margin-right:auto}\n"] }]
        }], ctorParameters: function () { return [{ type: BsNavbarComponent }]; }, propDecorators: { collapse: [{
                type: Input
            }], onWindowResize: [{
                type: HostListener,
                args: ['window:resize']
            }] } });

class BsNavbarItemComponent {
    constructor(navbar, element, destroy, platformId, parentDropdown) {
        this.navbar = navbar;
        this.destroy = destroy;
        this.platformId = platformId;
        this.hasDropdown = false;
        this.anchorTag = null;
        this.element = element;
        this.parentDropdown = parentDropdown;
    }
    ngAfterContentChecked() {
        this.anchorTag = this.element.nativeElement.querySelector('li a');
        if (this.hasDropdown) {
            if (this.anchorTag) {
                this.anchorTag.classList.add('dropdown-toggle');
                if (isPlatformServer(this.platformId)) {
                    this.anchorTag.href = 'javascript:;';
                }
                if (!this.anchorTag.getAttribute('close-init-b')) {
                    this.anchorTag.setAttribute('close-init-b', '1');
                    this.anchorTag.addEventListener('click', (ev) => {
                        ev.preventDefault();
                        // Normally there should be only one dropdown in this list
                        this.dropdowns.forEach((dropdown) => {
                            if (!(dropdown.isVisible = !dropdown.isVisible)) {
                                dropdown.childDropdowns.forEach((child) => child.isVisible = false);
                            }
                            else if (this.parentDropdown) {
                                // import('@angular/cdk/overlay').then(({ OverlayModule, Overlay }) => {
                                //   const overlayService = this.injector.get(Overlay);
                                //   return overlayService;
                                // }).then((overlayService) => {
                                //   const p = new DomPortal(dropdown.element);
                                //   const overlayRef = overlayService.create({
                                //     positionStrategy: overlayService.position()
                                //       .flexibleConnectedTo(this.element)
                                //       .withPositions([
                                //         { originX: 'end', originY: 'top', overlayX: 'start', overlayY: 'top' }
                                //       ])
                                //   });
                                // overlayRef.attach(p);
                                // });
                                // dropdown.showInOverlay = true;
                                this.navbar.isSmallMode$
                                    .pipe(takeUntilDestroyed(this.destroy))
                                    .subscribe((isSmallMode) => dropdown.showInOverlay = !isSmallMode);
                            }
                        });
                        return false;
                    });
                }
            }
        }
        else {
            // Close if this is a link
            if ((this.dropdowns.length === 0) && this.anchorTag && !this.anchorTag.getAttribute('close-init-a')) {
                this.anchorTag.setAttribute('close-init-a', '1');
                this.anchorTag.addEventListener('click', (ev) => {
                    let d = this.parentDropdown;
                    while (d && d.autoclose) {
                        d.isVisible = false;
                        d = d.parentDropdown;
                    }
                    if (this.navbar.autoclose) {
                        this.navbar.isExpanded$.next(false);
                    }
                });
            }
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsNavbarItemComponent, deps: [{ token: BsNavbarComponent }, { token: i0.ElementRef }, { token: i0.DestroyRef }, { token: PLATFORM_ID }, { token: BsNavbarDropdownComponent, optional: true }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.1.2", type: BsNavbarItemComponent, selector: "bs-navbar-item", queries: [{ propertyName: "dropdowns", predicate: i0.forwardRef(function () { return BsNavbarDropdownComponent; }) }], ngImport: i0, template: "<li [class.nav-item]=\"parentDropdown === null\" [class.dropdown]=\"(dropdowns.length > 0) && (parentDropdown === null)\" [class.dropend]=\"(dropdowns.length > 0) && (parentDropdown !== null)\">\n    <ng-content></ng-content>\n</li>", styles: ["li.dropend ::ng-deep a.dropdown-toggle{padding-right:1.5rem}li.dropend ::ng-deep a.dropdown-toggle:after{position:absolute;right:.5rem;top:.75rem}\n"] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsNavbarItemComponent, decorators: [{
            type: Component,
            args: [{ selector: 'bs-navbar-item', template: "<li [class.nav-item]=\"parentDropdown === null\" [class.dropdown]=\"(dropdowns.length > 0) && (parentDropdown === null)\" [class.dropend]=\"(dropdowns.length > 0) && (parentDropdown !== null)\">\n    <ng-content></ng-content>\n</li>", styles: ["li.dropend ::ng-deep a.dropdown-toggle{padding-right:1.5rem}li.dropend ::ng-deep a.dropdown-toggle:after{position:absolute;right:.5rem;top:.75rem}\n"] }]
        }], ctorParameters: function () { return [{ type: BsNavbarComponent }, { type: i0.ElementRef }, { type: i0.DestroyRef }, { type: Object, decorators: [{
                    type: Inject,
                    args: [PLATFORM_ID]
                }] }, { type: BsNavbarDropdownComponent, decorators: [{
                    type: Optional
                }] }]; }, propDecorators: { dropdowns: [{
                type: ContentChildren,
                args: [forwardRef(() => BsNavbarDropdownComponent)]
            }] } });

class BsNavbarDropdownComponent {
    constructor(navbar, parentDropdown, navbarItem, element, injector, document, platformId) {
        this.navbar = navbar;
        this.element = element;
        this.injector = injector;
        this.document = document;
        this.isAttached = false;
        this.autoclose = true;
        this.isBrowser = false;
        this.topPos$ = new BehaviorSubject(null);
        //#region IsVisible
        this.isVisible$ = new BehaviorSubject(false);
        this.parentDropdown = parentDropdown;
        this.navbarItem = navbarItem;
        this.isBrowser = !isPlatformServer(platformId);
        this.isVisible$.pipe(takeUntilDestroyed()).subscribe((isVisible) => {
            if (isVisible) {
                setTimeout(() => {
                    try {
                        this.overlay && this.overlay.updatePosition();
                    }
                    catch (ex) { }
                }, 20);
                this.topPos$.next(this.element.nativeElement.offsetTop);
            }
            else {
                this.topPos$.next(null);
            }
        });
        this.maxHeight$ = this.topPos$.pipe(map((topPos) => {
            const w = this.document.defaultView;
            if (!topPos) {
                return null;
            }
            else if (w) {
                const style = w.getComputedStyle(this.dropdownElement.nativeElement);
                return `calc(100vh - ${topPos}px - ${style.getPropertyValue('padding-top')} - ${style.getPropertyValue('padding-bottom')})`;
            }
            else {
                return null;
            }
        }));
        this.maxHeightOrNull$ = combineLatest([this.maxHeight$, this.navbar.isSmallMode$]).pipe(map(([maxHeight, isSmallMode]) => {
            if (isSmallMode) {
                return null;
            }
            else if (isPlatformServer(platformId)) {
                // Javascript disabled
                // Only apply max-height to the top-dropdown
                return parentDropdown ? null : maxHeight;
            }
            else {
                // If javascript enabled
                return maxHeight;
            }
        }));
        if (!!parentDropdown) {
            // Setup overlay
            import('@angular/cdk/overlay').then(({ OverlayModule, Overlay }) => {
                const overlayService = this.injector.get(Overlay);
                return overlayService;
            }).then((overlayService) => {
                this.domPortal = new DomPortal(this.element);
                this.overlay = overlayService.create({
                    positionStrategy: overlayService.position()
                        .flexibleConnectedTo(this.navbarItem.element)
                        .withPositions([
                        { originX: 'end', originY: 'top', overlayX: 'start', overlayY: 'top', offsetX: -9, offsetY: -9 }
                    ])
                });
                // For some reason we have to trigger this from the BsDropdownItem
                // this.showInOverlay = true;
            });
        }
    }
    set showInOverlay(value) {
        if (this.overlay && this.domPortal) {
            // if (value && !this.overlay.hasAttached()) {
            if (value && !this.isAttached) {
                this.overlay.attach(this.domPortal);
                this.isAttached = true;
            }
            if (!value && this.isAttached) {
                this.overlay.detach();
                this.isAttached = false;
            }
        }
    }
    get isVisible() {
        return this.isVisible$.value;
    }
    set isVisible(value) {
        this.isVisible$.next(value);
    }
    //#endregion
    get elementsToExclude() {
        return [this.navbarItem.anchorTag].filter((a) => a).map((a) => a);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsNavbarDropdownComponent, deps: [{ token: BsNavbarComponent }, { token: BsNavbarDropdownComponent, host: true, optional: true, skipSelf: true }, { token: forwardRef(() => BsNavbarItemComponent), host: true }, { token: i0.ElementRef }, { token: i0.Injector }, { token: DOCUMENT }, { token: PLATFORM_ID }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.1.2", type: BsNavbarDropdownComponent, selector: "bs-navbar-dropdown", inputs: { autoclose: "autoclose" }, queries: [{ propertyName: "childDropdowns", predicate: i0.forwardRef(function () { return BsNavbarDropdownComponent; }), descendants: true }], viewQueries: [{ propertyName: "dropdownElement", first: true, predicate: ["dd"], descendants: true }], ngImport: i0, template: "<bs-has-overlay></bs-has-overlay>\n<ul #dd class=\"dropdown-menu\" [class.show]=\"isVisible$ | async\" [class.submenu]=\"!!parentDropdown\" [class.overflow-y-auto]=\"isBrowser\" [style.max-height]=\"maxHeightOrNull$ | async\" bsNoNoscript (clickOutside)=\"isVisible = false\" [exclude]=\"elementsToExclude\" aria-labelledby=\"navbarDropdown\">\n    <ng-content></ng-content>\n</ul>\n\n<!-- \n    - Working demo: https://codepen.io/agop/pen/VwwMGR\n    - Location must be set through javascript\n    - bsNoScript => If noscript, 2nd-level submenus must be shown inside the 1st-level submenu\n -->\n <!-- \n    - Another option: https://stackblitz.com/edit/web-platform-vmsr4l?file=index.html\n    - But this doesn't seem to work here\n  -->", styles: [".submenu:not(.noscript){margin:0 .5rem!important}.submenu.noscript{margin:0 .5rem;position:initial!important}:not(.submenu).noscript{max-height:calc(100vh - 100% - 1rem);overflow-y:auto}.overflow-y-auto{overflow-y:auto}\n"], dependencies: [{ kind: "directive", type: i2$1.ClickOutsideDirective, selector: "[clickOutside]", inputs: ["clickOutsideEnabled", "attachOutsideOnClick", "delayClickOutsideInit", "emitOnBlur", "exclude", "excludeBeforeClick", "clickOutsideEvents"], outputs: ["clickOutside"] }, { kind: "directive", type: i4.BsNoNoscriptDirective, selector: "[bsNoNoscript]" }, { kind: "component", type: i4$1.BsHasOverlayComponent, selector: "bs-has-overlay" }, { kind: "pipe", type: i1.AsyncPipe, name: "async" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsNavbarDropdownComponent, decorators: [{
            type: Component,
            args: [{ selector: 'bs-navbar-dropdown', template: "<bs-has-overlay></bs-has-overlay>\n<ul #dd class=\"dropdown-menu\" [class.show]=\"isVisible$ | async\" [class.submenu]=\"!!parentDropdown\" [class.overflow-y-auto]=\"isBrowser\" [style.max-height]=\"maxHeightOrNull$ | async\" bsNoNoscript (clickOutside)=\"isVisible = false\" [exclude]=\"elementsToExclude\" aria-labelledby=\"navbarDropdown\">\n    <ng-content></ng-content>\n</ul>\n\n<!-- \n    - Working demo: https://codepen.io/agop/pen/VwwMGR\n    - Location must be set through javascript\n    - bsNoScript => If noscript, 2nd-level submenus must be shown inside the 1st-level submenu\n -->\n <!-- \n    - Another option: https://stackblitz.com/edit/web-platform-vmsr4l?file=index.html\n    - But this doesn't seem to work here\n  -->", styles: [".submenu:not(.noscript){margin:0 .5rem!important}.submenu.noscript{margin:0 .5rem;position:initial!important}:not(.submenu).noscript{max-height:calc(100vh - 100% - 1rem);overflow-y:auto}.overflow-y-auto{overflow-y:auto}\n"] }]
        }], ctorParameters: function () { return [{ type: BsNavbarComponent }, { type: BsNavbarDropdownComponent, decorators: [{
                    type: SkipSelf
                }, {
                    type: Host
                }, {
                    type: Optional
                }] }, { type: BsNavbarItemComponent, decorators: [{
                    type: Host
                }, {
                    type: Inject,
                    args: [forwardRef(() => BsNavbarItemComponent)]
                }] }, { type: i0.ElementRef }, { type: i0.Injector }, { type: Document, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }, { type: Object, decorators: [{
                    type: Inject,
                    args: [PLATFORM_ID]
                }] }]; }, propDecorators: { autoclose: [{
                type: Input
            }], dropdownElement: [{
                type: ViewChild,
                args: ['dd']
            }], childDropdowns: [{
                type: ContentChildren,
                args: [forwardRef(() => BsNavbarDropdownComponent), { descendants: true }]
            }] } });

class DropdownToggleDirective {
    constructor(elementRef, bsNavbarItem, parentDropdown) {
        this.elementRef = elementRef;
        this.bsNavbarItem = bsNavbarItem;
    }
    ngAfterContentInit() {
        if (this.bsNavbarItem.dropdowns.length > 0) {
            this.bsNavbarItem.hasDropdown = true;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: DropdownToggleDirective, deps: [{ token: i0.ElementRef }, { token: forwardRef(() => BsNavbarItemComponent) }, { token: forwardRef(() => BsNavbarDropdownComponent), optional: true }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.1.2", type: DropdownToggleDirective, selector: "bs-navbar-item", queries: [{ propertyName: "childDropdowns", predicate: BsNavbarDropdownComponent }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: DropdownToggleDirective, decorators: [{
            type: Directive,
            args: [{
                    // selector: 'bs-navbar-item > a[routerLink]',
                    selector: 'bs-navbar-item',
                    queries: {
                        childDropdowns: new ContentChildren(BsNavbarDropdownComponent)
                    }
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: BsNavbarItemComponent, decorators: [{
                    type: Inject,
                    args: [forwardRef(() => BsNavbarItemComponent)]
                }] }, { type: BsNavbarDropdownComponent, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [forwardRef(() => BsNavbarDropdownComponent)]
                }] }]; } });

class NavLinkDirective {
    constructor(elementRef, parentNavbar, parentDropdown) {
        this.elementRef = elementRef;
        if (parentNavbar) {
            if (parentDropdown == null) {
                this.elementRef.nativeElement.classList.add('nav-link');
            }
            else {
                this.elementRef.nativeElement.classList.add('dropdown-item');
            }
        }
        this.cursorPointer = !!parentNavbar;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: NavLinkDirective, deps: [{ token: i0.ElementRef }, { token: BsNavbarComponent, optional: true }, { token: forwardRef(() => BsNavbarDropdownComponent), optional: true }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.1.2", type: NavLinkDirective, selector: "bs-navbar-item > li > a", host: { properties: { "class.cursor-pointer": "this.cursorPointer" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: NavLinkDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'bs-navbar-item > li > a'
                    // Below selector doesn't work well either (does not select the github link)
                    // selector: 'bs-navbar-item > a[routerLink]'
                    // Below selector seems to target other a's that aren't even remotely inside a bs-navbar-item
                    // selector: 'bs-navbar-item:first-child > a'
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: BsNavbarComponent, decorators: [{
                    type: Optional
                }] }, { type: BsNavbarDropdownComponent, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [forwardRef(() => BsNavbarDropdownComponent)]
                }] }]; }, propDecorators: { cursorPointer: [{
                type: HostBinding,
                args: ['class.cursor-pointer']
            }] } });

class BsNavbarContentDirective {
    constructor(element, platformId) {
        this.element = element;
        this.platformId = platformId;
        this.viewInit$ = new BehaviorSubject(false);
        this.navbar$ = new BehaviorSubject(null);
        this.resizeObserver = null;
        this.initialPadding = 0;
        combineLatest([this.viewInit$, this.navbar$])
            .pipe(filter(([viewInit, navbar]) => viewInit && !!navbar))
            .pipe(take(1), takeUntilDestroyed())
            .subscribe(([viewInit, navbar]) => {
            if (isPlatformServer(platformId)) {
                this.element.nativeElement.style.paddingTop = (this.initialPadding + 58) + 'px';
            }
            else {
                // Initialize the ResizeObserver
                this.resizeObserver = new ResizeObserver((entries) => {
                    const height = navbar
                        ? navbar.nav.nativeElement.offsetHeight
                        : entries[0].contentRect.height;
                    this.element.nativeElement.style.paddingTop = (this.initialPadding + height) + 'px';
                });
                // Monitor the size
                const px = getComputedStyle(this.element.nativeElement).getPropertyValue('padding-top');
                const pt = parseInt(px.replace(/px$/, ''));
                this.initialPadding = isNaN(pt) ? 0 : pt;
                if (this.resizeObserver && navbar) {
                    this.resizeObserver.observe(navbar.nav.nativeElement);
                }
            }
        });
    }
    set navbar(value) {
        this.navbar$.next(value);
    }
    ngAfterViewInit() {
        this.viewInit$.next(true);
    }
    ngOnDestroy() {
        this.resizeObserver?.unobserve(this.navbar$.value?.nav.nativeElement);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsNavbarContentDirective, deps: [{ token: i0.ElementRef }, { token: PLATFORM_ID }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.1.2", type: BsNavbarContentDirective, selector: "[bsNavbarContent]", inputs: { navbar: ["bsNavbarContent", "navbar"] }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsNavbarContentDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[bsNavbarContent]'
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [PLATFORM_ID]
                }] }]; }, propDecorators: { navbar: [{
                type: Input,
                args: ['bsNavbarContent']
            }] } });

class BsNavbarBrandComponent {
    constructor() {
        this.routerLink = [];
        this.mxAuto = true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsNavbarBrandComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.1.2", type: BsNavbarBrandComponent, selector: "bs-navbar-brand", inputs: { routerLink: "routerLink" }, host: { properties: { "class.mx-auto": "this.mxAuto" } }, ngImport: i0, template: "<span class=\"navbar-brand mx-auto mx-md-unset\">\n    <ng-content></ng-content>\n</span>", styles: [""] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsNavbarBrandComponent, decorators: [{
            type: Component,
            args: [{ selector: 'bs-navbar-brand', template: "<span class=\"navbar-brand mx-auto mx-md-unset\">\n    <ng-content></ng-content>\n</span>" }]
        }], propDecorators: { routerLink: [{
                type: Input
            }], mxAuto: [{
                type: HostBinding,
                args: ['class.mx-auto']
            }] } });

class BsExpandButtonDirective {
    constructor(navbar, templateRef) {
        navbar.expandButtonTemplate = templateRef;
    }
    static ngTemplateContextGuard(dir, ctx) {
        return true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsExpandButtonDirective, deps: [{ token: BsNavbarComponent }, { token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.1.2", type: BsExpandButtonDirective, selector: "[bsExpandButton]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsExpandButtonDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[bsExpandButton]'
                }]
        }], ctorParameters: function () { return [{ type: BsNavbarComponent }, { type: i0.TemplateRef }]; } });
class BsExpandButtonContext {
    constructor() {
        this.$implicit = null;
    }
}

class BsNavbarTogglerComponent {
    constructor() {
        //#region State
        this._state = 'closed';
        this.stateChange = new EventEmitter();
        //#endregion
        this.toggleOnClick = true;
    }
    get state() {
        return this._state;
    }
    set state(value) {
        this._state = value;
        this.stateChange.emit(this._state);
    }
    toggleState(ev) {
        if (this.toggleOnClick) {
            switch (this._state) {
                case 'open':
                    this.state = 'closed';
                    break;
                default:
                    this.state = 'open';
                    break;
            }
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsNavbarTogglerComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.1.2", type: BsNavbarTogglerComponent, selector: "bs-navbar-toggler", inputs: { state: "state", toggleOnClick: "toggleOnClick" }, outputs: { stateChange: "stateChange" }, host: { listeners: { "click": "toggleState($event)" } }, ngImport: i0, template: "<div class=\"navbar-toggler float-left\" [ngClass]=\"state\">\n    <div></div>\n    <div></div>\n    <div></div>\n</div>", styles: [":host{align-self:start;top:0;right:0}.navbar-toggler{padding:.75rem 1rem;border:none}.navbar-toggler>div{width:25px;height:2px;background:#BBB;margin:6px 0;transition:.4s}.navbar-toggler.open>div:nth-of-type(1){transform:rotate(-45deg) translate(-7px,5px)}.navbar-toggler.open>div:nth-of-type(2){opacity:0}.navbar-toggler.open>div:nth-of-type(3){transform:rotate(45deg) translate(-6px,-4px)}@media (min-width: 768px){.navbar-toggler.auto>div:nth-of-type(1){transform:rotate(-45deg) translate(-7px,5px)}.navbar-toggler.auto>div:nth-of-type(2){opacity:0}.navbar-toggler.auto>div:nth-of-type(3){transform:rotate(45deg) translate(-6px,-4px)}}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsNavbarTogglerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'bs-navbar-toggler', template: "<div class=\"navbar-toggler float-left\" [ngClass]=\"state\">\n    <div></div>\n    <div></div>\n    <div></div>\n</div>", styles: [":host{align-self:start;top:0;right:0}.navbar-toggler{padding:.75rem 1rem;border:none}.navbar-toggler>div{width:25px;height:2px;background:#BBB;margin:6px 0;transition:.4s}.navbar-toggler.open>div:nth-of-type(1){transform:rotate(-45deg) translate(-7px,5px)}.navbar-toggler.open>div:nth-of-type(2){opacity:0}.navbar-toggler.open>div:nth-of-type(3){transform:rotate(45deg) translate(-6px,-4px)}@media (min-width: 768px){.navbar-toggler.auto>div:nth-of-type(1){transform:rotate(-45deg) translate(-7px,5px)}.navbar-toggler.auto>div:nth-of-type(2){opacity:0}.navbar-toggler.auto>div:nth-of-type(3){transform:rotate(45deg) translate(-6px,-4px)}}\n"] }]
        }], propDecorators: { stateChange: [{
                type: Output
            }], state: [{
                type: Input
            }], toggleOnClick: [{
                type: Input
            }], toggleState: [{
                type: HostListener,
                args: ['click', ['$event']]
            }] } });

class BsNavbarModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsNavbarModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.1.2", ngImport: i0, type: BsNavbarModule, declarations: [BsNavbarComponent,
            BsNavbarNavComponent,
            BsNavbarDropdownComponent,
            BsNavbarItemComponent,
            DropdownToggleDirective,
            NavLinkDirective,
            BsNavbarContentDirective,
            BsNavbarBrandComponent,
            BsExpandButtonDirective,
            BsNavbarTogglerComponent], imports: [CommonModule,
            ClickOutsideModule,
            BsContainerModule,
            BsUserAgentModule,
            BsNoNoscriptModule,
            BsHasOverlayModule,
            BsDropdownDividerModule], exports: [BsNavbarComponent,
            BsNavbarNavComponent,
            BsNavbarDropdownComponent,
            BsNavbarItemComponent,
            DropdownToggleDirective,
            NavLinkDirective,
            BsNavbarContentDirective,
            BsNavbarBrandComponent,
            BsExpandButtonDirective,
            BsNavbarTogglerComponent,
            BsDropdownDividerDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsNavbarModule, imports: [CommonModule,
            ClickOutsideModule,
            BsContainerModule,
            BsUserAgentModule,
            BsNoNoscriptModule,
            BsHasOverlayModule,
            BsDropdownDividerModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsNavbarModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        BsNavbarComponent,
                        BsNavbarNavComponent,
                        BsNavbarDropdownComponent,
                        BsNavbarItemComponent,
                        DropdownToggleDirective,
                        NavLinkDirective,
                        BsNavbarContentDirective,
                        BsNavbarBrandComponent,
                        BsExpandButtonDirective,
                        BsNavbarTogglerComponent,
                    ],
                    imports: [
                        CommonModule,
                        ClickOutsideModule,
                        BsContainerModule,
                        BsUserAgentModule,
                        BsNoNoscriptModule,
                        BsHasOverlayModule,
                        BsDropdownDividerModule,
                    ],
                    exports: [
                        BsNavbarComponent,
                        BsNavbarNavComponent,
                        BsNavbarDropdownComponent,
                        BsNavbarItemComponent,
                        DropdownToggleDirective,
                        NavLinkDirective,
                        BsNavbarContentDirective,
                        BsNavbarBrandComponent,
                        BsExpandButtonDirective,
                        BsNavbarTogglerComponent,
                        BsDropdownDividerDirective,
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { BsExpandButtonContext, BsExpandButtonDirective, BsNavbarBrandComponent, BsNavbarComponent, BsNavbarContentDirective, BsNavbarDropdownComponent, BsNavbarItemComponent, BsNavbarModule, BsNavbarNavComponent, BsNavbarTogglerComponent, DropdownToggleDirective, NavLinkDirective };
//# sourceMappingURL=mintplayer-ng-bootstrap-navbar.mjs.map
