import * as i0 from '@angular/core';
import { EventEmitter, Component, Output, Input, HostBinding, ViewChild, HostListener, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { BehaviorSubject } from 'rxjs';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';

class BsSignaturePadComponent {
    constructor() {
        //#region Signature
        this.signature$ = new BehaviorSubject({ strokes: [] });
        this.signatureChange = new EventEmitter();
        //#endregion
        this.width = 500;
        this.height = 300;
        this.classes = true;
        this.isDrawing = false;
        this.context = null;
        this.minHeight = 5;
        this.signature$.pipe(takeUntilDestroyed()).subscribe((signature) => {
            this.signatureChange.emit(signature);
        });
    }
    get signature() {
        return this.signature$.value;
    }
    set signature(value) {
        this.signature$.next(value);
    }
    ngAfterViewInit() {
        this.context = this.canvas.nativeElement.getContext('2d', { willReadFrequently: true });
    }
    onTouchMove(ev) {
        if (this.isDrawing) {
            ev.preventDefault();
        }
    }
    onPointerStart(ev) {
        ev.preventDefault();
        this.isDrawing = true;
        if (this.context) {
            this.signature.strokes.push({
                points: [{ x: ev.offsetX, y: ev.offsetY }]
            });
            this.signatureChange.emit(this.signature);
            this.context.fillStyle = 'black';
            this.context.beginPath();
            this.context.moveTo(ev.offsetX, ev.offsetY);
        }
    }
    onPointerMove(ev) {
        if (this.isDrawing && this.context) {
            ev.preventDefault();
            // this.context.moveTo(this.points.at(-1)!.x, this.points.at(-1)!.y);
            // // ctx.arc(x, y, width, 0, 2 * Math.PI, false);
            // // this.context.arc(ev.offsetX, ev.offsetY, 2, 0, 2 * Math.PI, false);
            // // this.context.arcTo(ev.offsetX, ev.offsetY,)
            // this.context.closePath();
            // this.context.fill();
            this.signature.strokes.at(-1)?.points.push({ x: ev.offsetX, y: ev.offsetY });
            this.signatureChange.emit(this.signature);
            this.context.lineTo(ev.offsetX, ev.offsetY);
            this.context.stroke();
        }
    }
    onPointerEnd(ev) {
        if (this.isDrawing && this.context) {
            ev.preventDefault();
            this.isDrawing = false;
            this.signatureChange.emit(this.signature);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsSignaturePadComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.1.2", type: BsSignaturePadComponent, selector: "bs-signature-pad", inputs: { signature: "signature", width: "width", height: "height" }, outputs: { signatureChange: "signatureChange" }, host: { listeners: { "touchmove": "onTouchMove($event)", "pointerdown": "onPointerStart($event)", "pointermove": "onPointerMove($event)", "window:pointerup": "onPointerEnd($event)" }, properties: { "class.border": "this.classes", "class.d-inline-block": "this.classes", "style.min-height.rem": "this.minHeight" } }, viewQueries: [{ propertyName: "canvas", first: true, predicate: ["canvas"], descendants: true }], ngImport: i0, template: "<canvas [width]=\"width\" [height]=\"height\" class=\"d-block\" #canvas></canvas>", styles: [""] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsSignaturePadComponent, decorators: [{
            type: Component,
            args: [{ selector: 'bs-signature-pad', template: "<canvas [width]=\"width\" [height]=\"height\" class=\"d-block\" #canvas></canvas>" }]
        }], ctorParameters: function () { return []; }, propDecorators: { signatureChange: [{
                type: Output
            }], signature: [{
                type: Input
            }], width: [{
                type: Input
            }], height: [{
                type: Input
            }], classes: [{
                type: HostBinding,
                args: ['class.border']
            }, {
                type: HostBinding,
                args: ['class.d-inline-block']
            }], canvas: [{
                type: ViewChild,
                args: ['canvas']
            }], minHeight: [{
                type: HostBinding,
                args: ['style.min-height.rem']
            }], onTouchMove: [{
                type: HostListener,
                args: ['touchmove', ['$event']]
            }], onPointerStart: [{
                type: HostListener,
                args: ['pointerdown', ['$event']]
            }], onPointerMove: [{
                type: HostListener,
                args: ['pointermove', ['$event']]
            }], onPointerEnd: [{
                type: HostListener,
                args: ['window:pointerup', ['$event']]
            }] } });

class BsSignaturePadModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsSignaturePadModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.1.2", ngImport: i0, type: BsSignaturePadModule, declarations: [BsSignaturePadComponent], imports: [CommonModule], exports: [BsSignaturePadComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsSignaturePadModule, imports: [CommonModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.2", ngImport: i0, type: BsSignaturePadModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [BsSignaturePadComponent],
                    imports: [CommonModule],
                    exports: [BsSignaturePadComponent],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { BsSignaturePadComponent, BsSignaturePadModule };
//# sourceMappingURL=mintplayer-ng-bootstrap-signature-pad.mjs.map
